/********************************************************************************
 *
 * @file	main.c
 * @brief	This is current-sample program for S1C17656 demonstration.
 *
 * @par		Copyright:
 *			Copyright(C) SEIKO EPSON CORPORATION 2014-2014. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 2014/08/20	1.00
 *				- First revision
 *
 *******************************************************************************/
/********************************************************************************
 * @mainpage	S1C17656 CURRENT
 *
 * @section		intro Introduction
 * Sample code makes a Halt state in the state that PCLK stopped,
 * RTC ran or stopped, and ran only OSC1A.
 * The code makes a Sleep state in the state that RTC ran or stopped.
 *
 * @subsection	step1	Step 1: Halt with OSC1A.
 *						Declare "HALT_OSC1A".
 *						Make a Halt state that PCLK and RTC stopped,
 *						and ran only OSC1A.
 * @subsection	step2	Step 2: Halt with OSC1A and RTC.
 *						Declare "HALT_OSC1A_RTC".
 *						Make a Halt state that PCLK stopped, RTC ran,
 *						and ran only OSC1A.
 * @subsection	step3	Step 3: Sleep.
 *						Declare "SLEEP_ONLY".
 *						Make a Sleep state that RTC stopped,
 *						and ran only OSC1A.
 * @subsection	step4	Step 4: Sleep with RTC.
 *						Declare "SLEEP_RTC".
 *						Make a Sleep state that RTC ran,
 *						and ran only OSC1A.
 *
 * @section		install Installation
 * Start the IDE and import the "s1c17656_current" project.
 *
 *******************************************************************************/

/// #include
#include <stdio.h>
#include <c17656_reg.h>
#include <init.h>
#include <rtc.h>
#include <clg.h>

/// Prototype
int main(void);

/****************************************************************************
 * Main function.
 *
 * @retval	1	Normality
 ***************************************************************************/
int main(void)
{
	int rnf;
	int rnf_main = 1;

	DebugModeMisc( 0 );			/// Misc Stop in Debug Mode
	DebugModePsc( 0 );			/// Prescaler Stop in Debug Mode
	SetClockGear( 0 );			/// Set Clock Gear *default=0x0
	ControlClg( 3 );			/// Run Clg

#ifdef HALT_OSC1A

	/// Start OSC1A
	rnf = StartOSC1();
	if( rnf == 0 ){
		puts("***  StartOSC1 ERROR  ***");
		rnf_main = 0;
	}

	int	i,n;

	for( i = 0 ; i < 61; i++ ){			/// Wait 16384 * 2000000/32768 Cycle
		for( n = 0 ; n < 16384; n++ ){
			asm ( "nop" );
		}
	}

	rnf = ChgOSC(2);
	if( rnf == 0 ){
		puts("***  ChgOSC ERROR  ***");
		rnf_main = 0;
	}
	rnf = StopOSC3B();
	if( rnf == 0 ){
		puts("***  StopOSC3B ERROR  ***");
		rnf_main = 0;
	}
	/// Stop RTC
	StopRTC();
	/// Stop PCLK
	ControlClg( 0 );
	/// Halt
	asm("halt");

#endif // HALT_OSC1A

#ifdef HALT_OSC1A_RTC

	/// Start OSC1A
	rnf = StartOSC1();
	if( rnf == 0 ){
		puts("***  StartOSC1 ERROR  ***");
		rnf_main = 0;
	}

	int	i,n;

	for( i = 0 ; i < 61; i++ ){			/// Wait 16384 * 2000000/32768 Cycle
		for( n = 0 ; n < 16384; n++ ){
			asm ( "nop" );
		}
	}

	rnf = ChgOSC(2);
	if( rnf == 0 ){
		puts("***  ChgOSC ERROR  ***");
		rnf_main = 0;
	}
	rnf = StopOSC3B();
	if( rnf == 0 ){
		puts("***  StopOSC3B ERROR  ***");
		rnf_main = 0;
	}
	/// Start RTC
	StartRTC();
	/// Stop PCLK
	ControlClg( 0 );
	/// Halt
	asm("halt");

#endif // HALT_OSC1A_RTC

#ifdef SLEEP_ONLY

	/// Start OSC1A
	rnf = StartOSC1();
	if( rnf == 0 ){
		puts("***  StartOSC1 ERROR  ***");
		rnf_main = 0;
	}

	int	i,n;

	for( i = 0 ; i < 61; i++ ){			/// Wait 16384 * 2000000/32768 Cycle
		for( n = 0 ; n < 16384; n++ ){
			asm ( "nop" );
		}
	}

	rnf = ChgOSC(2);
	if( rnf == 0 ){
		puts("***  ChgOSC ERROR  ***");
		rnf_main = 0;
	}
	rnf = StopOSC3B();
	if( rnf == 0 ){
		puts("***  StopOSC3B ERROR  ***");
		rnf_main = 0;
	}
	/// Stop RTC
	StopRTC();
	/// Sleep
	asm("slp");

#endif // SLEEP_ONLY

#ifdef SLEEP_RTC

	/// Start OSC1A
	rnf = StartOSC1();
	if( rnf == 0 ){
		puts("***  StartOSC1 ERROR  ***");
		rnf_main = 0;
	}

	int	i,n;

	for( i = 0 ; i < 61; i++ ){			/// Wait 16384 * 2000000/32768 Cycle
		for( n = 0 ; n < 16384; n++ ){
			asm ( "nop" );
		}
	}

	rnf = ChgOSC(2);
	if( rnf == 0 ){
		puts("***  ChgOSC ERROR  ***");
		rnf_main = 0;
	}
	rnf = StopOSC3B();
	if( rnf == 0 ){
		puts("***  StopOSC3B ERROR  ***");
		rnf_main = 0;
	}
	/// Start RTC
	StartRTC();
	/// Sleep
	asm("slp");

#endif // SLEEP_RTC


	return ( rnf_main );
}

