/****************************************************************************
 *
 * @file	rtc.h
 * @brief	This is rtc driver header file for S1C17656.
 *
 * @par		Copyright:
 *			Copyright(C) SEIKO EPSON CORPORATION 2014-2014. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 2014/08/20	1.00
 *				- First revision
 *
 ***************************************************************************/

#ifndef _RTC_H
#define _RTC_H

/// End Status
#define RTC_SET_NG				( 0 )						/// Fail
#define RTC_SET_OK				( 1 )						/// Success

/// RTC Run/Stop Select
#define RTC_STOP				( 0 )						///< Stop
#define RTC_RUN				( 1 )						///< Run

/// RTC Mode Select
#define RTC_BCD				( 1 )						///< BCD mode
#define RTC_12H				( 1 )						///< 12H

#define RTC_MAX				( 9 )						///< RTC counter max

/// RTC Time Counter Select
#define RTC_PM					( 0x01 )					///< PM
#define RTCSL					( 0x0f )					///< RTC 1-second counter
#define RTCSH					( 0x07 )					///< RTC 10-second counter
#define RTC_SMAX				( 0x59 )					///< RTC second counter max(BCD mode)
#define RTC_MIMAX				( 0x59 )					///< RTC minute counter max(BCD mode)
#define RTCMIL					( 0x0f )					///< RTC 1-minute counter
#define RTCMIH					( 0x07 )					///< RTC 10-minute counter
#define RTCHL					( 0x0f )					///< RTC 1-hour counter
#define RTC_HMAX				( 0x23 )					///< RTC hour counter max(BCD mode)

/// RTC Interrupt Level Select
#define RTC_INT_LEVEL0			( 0x0 )						///< Interrupt priorities 0
#define RTC_INT_LEVEL1			( 0x1 )						///< Interrupt priorities 1
#define RTC_INT_LEVEL2			( 0x2 )						///< Interrupt priorities 2
#define RTC_INT_LEVEL3			( 0x3 )						///< Interrupt priorities 3
#define RTC_INT_LEVEL4			( 0x4 )						///< Interrupt priorities 4
#define RTC_INT_LEVEL5			( 0x5 )						///< Interrupt priorities 5
#define RTC_INT_LEVEL6			( 0x6 )						///< Interrupt priorities 6
#define RTC_INT_LEVEL7			( 0x7 )						///< Interrupt priorities 7

/// RTC Interrupt Enable/Disable Select
#define RTC_DISABLE			( 0 )						///< Disable
#define RTC_ENABLE				( 1 )						///< Enable

#define RTC_32HZINT_DISABLE	(0x0001*RTC_DISABLE)		///< 1/32 second interrupt disable
#define RTC_32HZINT_ENABLE		(0x0001*RTC_ENABLE)			///< 			   enable
#define RTC_8HZINT_DISABLE		(0x0002*RTC_DISABLE)		///<  1/8 second interrupt disable
#define RTC_8HZINT_ENABLE		(0x0002*RTC_ENABLE)			///< 			   enable
#define RTC_4HZINT_DISABLE		(0x0004*RTC_DISABLE)		///<  1/4 second interrupt disable
#define RTC_4HZINT_ENABLE		(0x0004*RTC_ENABLE)			///< 			   enable
#define RTC_1HZINT_DISABLE		(0x0008*RTC_DISABLE)		///<  1/1 second interrupt disable
#define RTC_1HZINT_ENABLE		(0x0008*RTC_ENABLE)			///< 			   enable
#define RTC_10SECINT_DISABLE	(0x0010*RTC_DISABLE)		///<   10 second interrupt disable
#define RTC_10SECINT_ENABLE	(0x0010*RTC_ENABLE)			///< 			   enable
#define RTC_1MININT_DISABLE	(0x0020*RTC_DISABLE)		///<    1 minute interrupt disable
#define RTC_1MININT_ENABLE		(0x0020*RTC_ENABLE)			///< 			   enable
#define RTC_10MININT_DISABLE	(0x0040*RTC_DISABLE)		///<   10 minute interrupt disable
#define RTC_10MININT_ENABLE	(0x0040*RTC_ENABLE)			///< 			   enable
#define RTC_1HURINT_DISABLE	(0x0080*RTC_DISABLE)		///<    1 hour   interrupt disable
#define RTC_1HURINT_ENABLE		(0x0080*RTC_ENABLE)			///< 			   enable
#define RTC_HDAYINT_DISABLE	(0x0100*RTC_DISABLE)		///< Half day    interrupt disable
#define RTC_HDAYINT_ENABLE		(0x0100*RTC_ENABLE)			///< 			   enable
#define RTC_1DAYINT_DISABLE	(0x0200*RTC_DISABLE)		///<    1 day    interrupt disable
#define RTC_1DAYINT_ENABLE		(0x0200*RTC_ENABLE)			///< 			   enable

/// RTC Interrupt Flag Occurred
#define RTC_OCCURRED			( 1 )						///< Occurred

#define RTC_32HZINT_OCCURRED	(0x0001*RTC_OCCURRED)		///<  1/32 second occurred
#define RTC_8HZINT_OCCURRED	(0x0002*RTC_OCCURRED)		///<  1/8  second occurred
#define RTC_4HZINT_OCCURRED	(0x0004*RTC_OCCURRED)		///<  1/4  second occurred
#define RTC_1HZINT_OCCURRED	(0x0008*RTC_OCCURRED)		///<  1/1  second occurred
#define RTC_10SECINT_OCCURRED	(0x0010*RTC_OCCURRED)		///<   10  second occurred
#define RTC_1MININT_OCCURRED	(0x0020*RTC_OCCURRED)		///<    1  minute occurred
#define RTC_10MININT_OCCURRED	(0x0040*RTC_OCCURRED)		///<   10  minute occurred
#define RTC_1HURINT_OCCURRED	(0x0080*RTC_OCCURRED)		///<    1  hour   occurred
#define RTC_HDAYINT_OCCURRED	(0x0100*RTC_OCCURRED)		///< Half  day    occurred
#define RTC_1DAYINT_OCCURRED	(0x0200*RTC_OCCURRED)		///<    1  day    occurred

/// RTC Interrupt Flag Reset
#define RTC_RESET				( 1 )						///< Reset

#define RTC_32HZINT_RESET		(0x0001*RTC_RESET)			///< 1/32 second flag reset
#define RTC_8HZINT_RESET		(0x0002*RTC_RESET)			///<  1/8 second flag reset
#define RTC_4HZINT_RESET		(0x0004*RTC_RESET)			///<  1/4 second flag reset
#define RTC_1HZINT_RESET		(0x0008*RTC_RESET)			///<  1/1 second flag reset
#define RTC_10SECINT_RESET		(0x0010*RTC_RESET)			///<   10 second flag reset
#define RTC_1MININT_RESET		(0x0020*RTC_RESET)			///<    1 minute flag reset
#define RTC_10MININT_RESET		(0x0040*RTC_RESET)			///<   10 minute flag reset
#define RTC_1HURINT_RESET		(0x0080*RTC_RESET)			///<    1 hour   flag reset
#define RTC_HDAYINT_RESET		(0x0100*RTC_RESET)			///< Half day    flag reset
#define RTC_1DAYINT_RESET		(0x0200*RTC_RESET)			///<    1 day    flag reset

/// RTC Interrupt Max
#define RTC_INT_MASK		(0x03ff)						///< interrupt mask data

/// RTC Set Data.
struct tag_RTC_DATE_INFO;
typedef struct tag_RTC_DATE_INFO {
	unsigned short		bcdmd;				/// BCD mode
	unsigned short		rtc24H;				/// 24H/12H mode
	unsigned short		second;				/// second counter data
	unsigned short		minute;				/// minute counter data
	unsigned short		hour;				/// hour counter data
	unsigned short		indicator;			/// indicator (AM/PM)
} RTC_DATE_INFO;


extern int InitRTC( RTC_DATE_INFO *pDate );
extern void StartRTC( void );
extern void StopRTC( void );
extern int InitRTCInt( unsigned char intLevel );
extern int EnableRTCInt( unsigned short intSelect );
extern int DisableRTCInt( unsigned short intSelect );
extern int isRTCInt( unsigned short intType );
extern int ClrRTCIntFlg( unsigned short intType );

#endif	//_RTC_H


