/***************************************************************************
 *
 * @file	spi_reg.h
 * @brief	This is Bit field for SPI register.
 *
 * @par		Copyright:
 *			Copyright (C) SEIKO EPSON CORPORATION 2013. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 22 Oct, 2013	1.00
 *				- First revision.
 *
 **************************************************************************/

#ifndef	SPI_REG_H__
#define	SPI_REG_H__

#ifdef	__cplusplus
extern "C" {
#endif


/// SPI Ch.0 Status Register.
typedef union SPI_STN_REG_TAG {
	unsigned short			reg;
	struct SPI_STN_REG_BIT_TAG {
		unsigned short		SPTBE		: 1;
		unsigned short		SPRBF		: 1;
		unsigned short		SPBSY		: 1;
		unsigned short		reserved_1	: 13;
	} bit;
	unsigned char byte_reg[2];
} SPI_STN_REG;

/// SPI Ch.0 Transmit Data Register.
typedef union SPI_TXDN_REG_TAG {
	unsigned short			reg;
	struct SPI_TXDN_REG_BIT_TAG {
		unsigned short		SPTDB		: 8;
		unsigned short		reserved_1	: 8;
	} bit;
	unsigned char byte_reg[2];
} SPI_TXDN_REG;

/// SPI Ch.0 Receive Data Register.
typedef union SPI_RXDN_REG_TAG {
	unsigned short			reg;
	struct SPI_RXDN_REG_BIT_TAG {
		unsigned short		SPRDB		: 8;
		unsigned short		reserved_1	: 8;
	} bit;
	unsigned char byte_reg[2];
} SPI_RXDN_REG;

/// SPI Ch.0 Control Register.
typedef union SPI_CTLN_REG_TAG {
	unsigned short			reg;
	struct SPI_CTLN_REG_BIT_TAG {
		unsigned short		SPEN		: 1;
		unsigned short		MSSL		: 1;
		unsigned short		CPOL		: 1;
		unsigned short		CPHA		: 1;
		unsigned short		SPTIE		: 1;
		unsigned short		SPRIE		: 1;
		unsigned short		reserved_1	: 2;
		unsigned short		MLSB		: 1;
		unsigned short		MCLK		: 1;
		unsigned short		reserved_2	: 6;
	} bit;
	unsigned char byte_reg[2];
} SPI_CTLN_REG;


#ifdef __cplusplus
}
#endif

#endif	// SPI_REG_H__


