/****************************************************************************
 *
 * @file	lcd.h
 * @brief	This is lcd driver header file for S1C17656.
 *
 * @par		Copyright:
 *			Copyright(C) SEIKO EPSON CORPORATION 2014-2014. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 2014/08/20	1.00
 *				- First revision
 *
 ***************************************************************************/

#ifndef LCD_H_
#define LCD_H_

extern int  InitLCDPower( unsigned char selectBclkd, unsigned char selectBclksrc,
							unsigned char selectLcdbclke, unsigned char selectMode, unsigned char selectVoltage);
extern int  InitLCD( unsigned char selectlcdtclk, unsigned char selectlcdtclkd, unsigned char selectdsprev,
			 		unsigned char selectdspc, unsigned char selectfrmcnt, unsigned char selectlduty );
extern int  SetLCDDisplay1Seg( unsigned char *seg, unsigned char com, unsigned char data );
extern void StartLCDClock( void );
extern void StopLCDClock( void );
extern short InitLCDInt( unsigned char intLevel );
extern void EnableLCDInt( void );
extern void DisableLCDInt( void );
extern int  isLCDInt(void);
extern void ClrLCDIntFlg( void );

/// End Status
#define LCD_SET_NG					( 0 )		///< Fail
#define LCD_SET_OK					( 1 )		///< Success

/// LCD Enable/Disable Select
#define LCDTCLKLCDTCLKE_ENABLE		( 1 )		///< Enable
#define LCDTCLKLCDTCLKE_DISABLE	( 0 )		///< Disable
#define LCDBCLKLCDTCLKE_ENABLE		( 1 )		///< Enable
#define LCDBCLKLCDTCLKE_DISABLE	( 0 )		///< Disable
#define LCDIMSKIFRMEN_ENABLE		( 1 )		///< On
#define LCDIMSKIFRMEN_DISABLE		( 0 )		///< Off

/// LCD Interrupt Occurred/Not Occurred Select
#define LCDIFLGIFRMLG_OCCURRED		( 1 )		///< Occurred
#define LCDIFLGIFRMLG_NOTOCCURED	( 0 )		///< Not Occurred

/// Vc Heavy Load Protection Mode On/Off
#define LCDVREGLHVLD_ON			( 1 )		///< On
#define LCDVREGLHVLD_OFF			( 0 )		///< Off

/// Reference Voltage Select
#define LCDVREGVCSEL_VC2			( 1 )		///< Vc2
#define LCDVREGVCSEL_VC1			( 0 )		///< Vc1

/// Reverse Display Control
#define LCDTDCTLDSPREV_NORMAL		( 1 )		///< Normal

/// LCD Booster Clock Division Ratio Select
#define BCLKDIV_3B64				( 0 )		///< OSC3B:1/64,OSC3A:1/128
#define BCLKDIV_3B128				( 1 )		///< OSC3B:1/128,OSC3A:1/256
#define BCLKDIV_3B256				( 2 )		///< OSC3B:1/256,OSC3A:1/512
#define BCLKDIV_3B512				( 3 )		///< OSC3B:1/512,OSC3A:1/1024
#define BCLKDIV_3B1024				( 4 )		///< OSC3B:1/1024,OSC3A:1/2048
#define BCLKDIV_3B2048				( 5 )		///< OSC3B:1/2048,OSC3A:1/4096
#define BCLKDIV_3B4096				( 6 )		///< OSC3B:1/4096,OSC3A:1/8192

#define BCLKDIV_OSC1_8				( 0 )		///< OSC1 : 1/8
#define BCLKDIV_OSC1_16			( 1 )		///< OSC1 : 1/16
#define BCLKDIV_OSC1_32			( 2 )		///< OSC1 : 1/32
#define BCLKDIV_OSC1_64			( 3 )		///< OSC1 : 1/64


/// LCD Clock Division Ratio Select
#define LCD_CLKDIV_1024			( 0 )		///< 1/1024
#define LCD_CLKDIV_2048			( 1 )		///< 1/2048
#define LCD_CLKDIV_4096			( 2 )		///< 1/4096
#define LCD_CLKDIV_8192			( 3 )		///< 1/8192

/// LCD Clock Source Select
#define LCD_CLKSRC_OSC3B			( 0 )		///< OSC3B
#define LCD_CLKSRC_OSC1			( 1 )		///< OSC1

/// LCD Display Control Select
#define LCD_DSPOFF					( 0 )		///< Display Off
#define LCD_NMRDSP					( 1 )		///< Normal Display
#define LCD_ALLON					( 2 )		///< All On
#define LCD_ALLOFF					( 3 )		///< All Off

/// LCD Frame Frequency Select
#define LCD_FREQ_4					( 0 )		///< 1/4
#define LCD_FREQ_8					( 1 )		///< 1/8
#define LCD_FREQ_12				( 2 )		///< 1/12
#define LCD_FREQ_16				( 3 )		///< 1/16

/// LCD Duty Select
#define LCD_DUTY_STATIC			( 0 )		///< Static
#define LCD_DUTY_2					( 1 )		///< 1/2
#define LCD_DUTY_3					( 2 )		///< 1/3
#define LCD_DUTY_4					( 3 )		///< 1/4

/// LCD Data Turn on/off a Light
#define LCD_DATA_TURNOFF			( 0 )		///< LCD Data Turn off
#define LCD_DATA_TURNON			( 1 )		///< LCD Data Turn on

/// LCD Interrupt Level Select
#define LCD_INTLV_0				( 0 )		///< Interrupt Level 0
#define LCD_INTLV_1				( 1 )		///< Interrupt Level 1
#define LCD_INTLV_2				( 2 )		///< Interrupt Level 2
#define LCD_INTLV_3				( 3 )		///< Interrupt Level 3
#define LCD_INTLV_4				( 4 )		///< Interrupt Level 4
#define LCD_INTLV_5				( 5 )		///< Interrupt Level 5
#define LCD_INTLV_6				( 6 )		///< Interrupt Level 6
#define LCD_INTLV_7				( 7 )		///< Interrupt Level 7

/// LCD Interrupt Reset
#define LCD_INT_RESET				( 1 )		///< Interrupt Reset

/// LCD SEG / COM No.
enum {
	LCD_SEG00 = 0x00,							///< 00 : SEG00
	LCD_SEG01,									///< 01 : SEG01
	LCD_SEG02,									///< 02 : SEG02
	LCD_SEG03,									///< 03 : SEG03
	LCD_SEG04,									///< 04 : SEG04
	LCD_SEG05,									///< 05 : SEG05
	LCD_SEG06,									///< 06 : SEG06
	LCD_SEG07,									///< 07 : SEG07
	LCD_SEG08,									///< 08 : SEG08
	LCD_SEG09,									///< 09 : SEG09
	LCD_SEG10,									///< 10 : SEG10
	LCD_SEG11,									///< 11 : SEG11
	LCD_SEG12,									///< 12 : SEG12
	LCD_SEG13,									///< 13 : SEG13
	LCD_SEG14,									///< 14 : SEG14
	LCD_SEG15,									///< 15 : SEG15
	LCD_SEG16,									///< 16 : SEG16
	LCD_SEG17,									///< 17 : SEG17
	LCD_SEG18,									///< 18 : SEG18
	LCD_SEG19,									///< 19 : SEG19
	LCD_SEG20,									///< 20 : SEG20
	LCD_SEG21,									///< 21 : SEG21
	LCD_SEG22,									///< 22 : SEG22
	LCD_SEG23,									///< 23 : SEG23
	LCD_SEG24,									///< 24 : SEG24
	LCD_SEG25,									///< 25 : SEG25
	LCD_SEG26,									///< 26 : SEG26
	LCD_SEG27,									///< 27 : SEG27
	LCD_SEG28,									///< 28 : SEG28
	LCD_SEG29,									///< 29 : SEG29
	LCD_SEG30,									///< 30 : SEG30
	LCD_SEG31,									///< 31 : SEG31
};

#define LCD_SEG_MAX				( 32 )		///< LCD segment MAX status(C17653)

enum {
	LCD_COM00 = 0x00,							///< 00 : COM00
	LCD_COM01,									///< 01 : COM01
	LCD_COM02,									///< 02 : COM02
	LCD_COM03,									///< 03 : COM03

	LCD_COM_MAX
};

#endif // LCD_H_

