/****************************************************************************
 *
 * @file	main.c
 * @brief	This is lcd-sample program for S1C17656 demonstration.
 *
 * @par		Copyright:
 *			Copyright(C) SEIKO EPSON CORPORATION 2014-2014. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 2014/08/20	1.00
 *				- First revision
 *
 ***************************************************************************/
/****************************************************************************
 * @mainpage	S1C17656 LCD
 *
 * @section		intro Introduction
 * Sample code turns off the display whether the turns on the display.
 * The code inputs commands to simulated I/O window, and controls LCD display.
 *
 * @subsection	step1	Step 1: Turn on LCD display by ALL ON.
 *						Input "on1" to simulated I/O window.
 *						Turn on LCD display by ALL ON.
 * @subsection	step2	Step 2: Turn off LCD display by ALL OFF.
 *						Input "off1" to simulated I/O window.
 *						Turn on LCD display by ALL OFF.
 * @subsection	step3	Step 3: Turn on LCD display by NORMAL DISPLAY.
 *						Input "on0" to simulated I/O window.
 *						Turn on LCD display by NORMAL DISPLAY.
 * @subsection	step4	Step 4: Turn off LCD display by DOSPLAY OFF.
 *						Input "off0" to simulated I/O window.
 *						Turn off LCD display by DISPLAY OFF.
 *
 * @section		install Installation
 * Start the IDE and import the "s1c17656_lcd" project.
 *
 ***************************************************************************/


/// #include
#include <string.h>
#include <stdio.h>
#include <c17656_reg.h>
#include <init.h>
#include <lcd.h>

/// Prototype
int main(void);

/// commands
#define LCD_ON_CMD			"on1"	///< ALL ON command
#define LCD_OFF_CMD		"off1"	///< ALL OFF command
#define LCD_SEGON_CMD		"on0"	///< NORMAL DISPlAY command
#define LCD_SEGOFF_CMD		"off0"	///< DISPLAY OFF command
#define LCD_MAIN_END_CMD	"exit"	///< EXIT command

/****************************************************************************
 * Main function.
 *
 * @retval	1	Normality
 * @retval	0	Abnormality
 ***************************************************************************/
int main(void)
{
	unsigned char inputCommand[5];
	unsigned char endFlag;
	int rnf;
	int rnf_main = 1;

	DebugModeMisc( 0 );			/// Misc Stop in Debug Mode
	DebugModePsc( 0 );			/// Prescaler Stop in Debug Mode
	SetClockGear( 0 );			/// Set Clock Gear *default=0x0
	ControlClg( 3 );			/// Run Clg

	printf( "<<< LCD driver demonstration start >>>\n" );

	/// LCD Power Set
	rnf = InitLCDPower( 4, 0, 1, 0, 0);
	if( rnf == 0 ){
		printf("***  InitLCDPower ERROR  ***\n");
		rnf_main = 0;
	}

	/// Initialize LCD
	rnf = InitLCD( 0, 0, 1, 0, 1, 3);
	if( rnf == 0 ){
		printf("***  InitLCD ERROR  ***\n");
		rnf_main = 0;
	}

	/// LCD Clock Start
	StartLCDClock();

	/// Set endFlag = 0
	endFlag = 0;

	while( 1 ){

		unsigned char *getCommand[5];

		/// User Input Command
		*getCommand = fgets( inputCommand, sizeof(inputCommand), stdin);

		if( strncmp(*getCommand, "on1", 3) == 0 ){
			/// Set LCD All On
			LCD_DCTL = (LCD_DCTL & 0xfc) | 2;
		} else if( strncmp(*getCommand, "off1", 4) == 0 ){
			/// Set LCD All Off
			LCD_DCTL = (LCD_DCTL & 0xfc) | 3;
		} else if( strncmp(*getCommand, "off2", 4) == 0 ){
			/// Set LCD Display Off
			LCD_DCTL = (LCD_DCTL & 0xfc) | 0;
		} else if( strncmp(*getCommand,"on0", 3) == 0 ){
			/// Set LCD Normal Display
			LCD_DCTL = (LCD_DCTL & 0xfc) | 1;
			/// 1-segment on
			rnf = SetLCDDisplay1Seg((unsigned char*)LCD_SEG31, (unsigned char)LCD_COM03, 1);
			if( rnf == 0 ){
				printf("***  SetLCDDisplay1Seg ERROR  ***\n");
				rnf_main = 0;
			}
		} else if( strncmp(*getCommand, "off0", 4) == 0 ){
			/// Set LCD Normal Display
			LCD_DCTL = (LCD_DCTL & 0xfc) | 1;
			/// 1-segment off
			rnf = SetLCDDisplay1Seg((unsigned char*)LCD_SEG31 , (unsigned char)LCD_COM03, 0);
			if( rnf == 0 ){
				printf("***  SetLCDDisplay1Seg ERROR  ***\n");
				rnf_main = 0;
			}
		} else if( strncmp(*getCommand, "exit", 4) == 0 ){
			endFlag = 1;
		} else {
			;
		}

		if( endFlag == 1 ){
			break;
		}

	}

	printf( "<<< LCD driver demonstration finish >>>\n" );

	StopLCDClock();

	/// LCD Power Set
	rnf = InitLCDPower(  0, 0, 0, 0, 0);
	if( rnf == 0 ){
		printf("***  InitLCDPower ERROR  ***\n");
		rnf_main = 0;
	}

	return ( rnf_main );
}

