/***************************************************************************
 *
 * @file	rtc_reg.h
 * @brief	This is Bit field for RTC register.
 *
 * @par		Copyright:
 *			Copyright (C) SEIKO EPSON CORPORATION 2013. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 22 Oct, 2013	1.00
 *				- First revision.
 *
 **************************************************************************/

#ifndef RTC_REG_H__
#define RTC_REG_H__

#ifdef	__cplusplus
extern "C" {
#endif


/// RTC Control Register.
typedef union RTC_CTL_REG_TAG {
	unsigned short			reg;
	struct RTC_CTL_REG_BIT_TAG {
		unsigned short		RTCRUN		: 1;
		unsigned short		reserved_1	: 3;
		unsigned short		RTC24H		: 1;
		unsigned short		BCDMD		: 1;
		unsigned short		reserved_2	: 2;
		unsigned short		RTCST		: 1;
		unsigned short		reserved_3	: 7;
	} bit;
	unsigned char byte_reg[2];
} RTC_CTL_REG;

/// RTC Interrupt Enable Register.
typedef union RTC_IEN_REG_TAG {
	unsigned short			reg;
	struct RTC_IEN_REG_BIT_TAG {
		unsigned short		INT32HZEN	: 1;
		unsigned short		INT8HZEN	: 1;
		unsigned short		INT4HZEN	: 1;
		unsigned short		INT1HZEN	: 1;
		unsigned short		INT10SEN	: 1;
		unsigned short		INT1MEN		: 1;
		unsigned short		INT10MEN	: 1;
		unsigned short		INT1HEN		: 1;
		unsigned short		INTHDEN		: 1;
		unsigned short		INT1DEN		: 1;
		unsigned short		reserved_1	: 6;
	} bit;
	unsigned char byte_reg[2];
} RTC_IEN_REG;

/// RTC Interrupt Flag Register.
typedef union RTC_IFLG_REG_TAG {
	unsigned short			reg;
	struct RTC_IFLG_REG_BIT_TAG {
		unsigned short		INT32HZ		: 1;
		unsigned short		INT8HZ		: 1;
		unsigned short		INT4HZ		: 1;
		unsigned short		INT1HZ		: 1;
		unsigned short		INT10S		: 1;
		unsigned short		INT1M		: 1;
		unsigned short		INT10M		: 1;
		unsigned short		INT1H		: 1;
		unsigned short		INTHD		: 1;
		unsigned short		INT1D		: 1;
		unsigned short		reserved_1	: 6;
	} bit;
	unsigned char byte_reg[2];
} RTC_IFLG_REG;

/// RTC Minute/Second Counter Register.
typedef union RTC_MS_REG_TAG {
	unsigned short			reg;
	struct RTC_MS_REG_BIT_TAG {
		unsigned short		RTCSEC		: 7;
		unsigned short		reserved_1	: 1;
		unsigned short		RTCMIN		: 7;
		unsigned short		reserved_2	: 1;
	} bit;
	unsigned char byte_reg[2];
} RTC_MS_REG;

/// RTC Hour Counter Register.
typedef union RTC_H_REG_TAG {
	unsigned short			reg;
	struct RTC_H_REG_BIT_TAG {
		unsigned short		RTCHOUR		: 6;
		unsigned short		reserved_1	: 1;
		unsigned short		AMPM		: 1;
		unsigned short		reserved_2	: 8;
	} bit;
	unsigned char byte_reg[2];
} RTC_H_REG;


#ifdef __cplusplus
}
#endif

#endif	// RTC_REG_H__


