/****************************************************************************
 *
 * @file	main.c
 * @brief	This is rfc-sample program for S1C17656 demonstration.
 *
 * @par		Copyright:
 *			Copyright(C) SEIKO EPSON CORPORATION 2014-2014. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 2014/08/20	1.00
 *				- First revision
 *
 ***************************************************************************/
/***************************************************************************
 * @mainpage	S1C17656 R/F Converter (RFC)
 *
 * @section		intro Introduction
 * Converts the sensor resistance into a digital value by performing CR
 * oscillation and counting the oscillation clock.
 *
 * @subsection	step1	Step 1: Initialize and start OSC1A.
 * @subsection	step2	Step 2: The system clock set in OSC1A.
 * @subsection	step3	Step 3: Initialize RFC.
 * @subsection	step4	Step 4: Run RFC and get measurement counter.
 * @subsection	step7	Step 5: Stop RFC.
 *
 * @section		install Installation
 * Start the IDE and import the "s1c17656_rfc" project.
 *
 **************************************************************************/

#include <string.h>
#include <stdio.h>
#include <c17656_reg.h>
#include <init.h>
#include <clg.h>
#include <rfc.h>


/* --- global variable --- */

int main(void);

/****************************************************************************
 * Main function.
 *
 * @retval	1	Normality
 * @retval	0	Abnormality
 ***************************************************************************/
int main(void)
{

	int rnf;
	int rnf_main = 1;
	unsigned long count = 0;
	int i,n;

	DebugModeMisc( 0 );			/// Misc Stop in Debug Mode
	DebugModePsc( 0 );			/// Prescaler Stop in Debug Mode
	SetClockGear( 0 );			/// Set Clock Gear *default=0x0
	ControlClg( 3 );			/// Run Clg

	/// OSC1A Wait Cycle
	rnf = SetWaitCycleClg( 0, 0 );
	if ( rnf == 0 ) {
		printf("***  SetWaitCycleClg ERROR  ***\n");
		rnf_main = 0;
	}

	/// Start OSC1
	rnf = StartOSC1();
	if ( rnf == 0 ) {
		printf("***  StartOSC1 ERROR  ***\n");
		rnf_main = 0;
	}

	for( i = 0 ; i < 61; i++ ){			/// Wait 16384 * 2000000/32768 Cycle
		for( n = 0 ; n < 16384; n++ ){
			asm ( "nop" );
		}
	}


	printf( "<<< R/F Converter demonstration start >>>\n" );

	/// Initialize RFC.
	rnf = initRfc();
	if ( rnf == 0 ) {
		printf("***  InitRFC ERROR  ***\n");
		rnf_main = 0;
	}

	/// Start Rfc.
	startRfc();

	/// Run RFC and get measurement counter.
	rnf = runRfcConvertingOperation( (unsigned long)0x00fc0000 , &count );
	if ( rnf != 0x0001 ) {
		printf("***  RFC Convert ERROR  ***\n");
		rnf_main = 0;
	}

	printf("*** Measurement Counter : %lu ***\n", count);

	stopRfc();

	printf( "<<< R/F Converter demonstration finish >>>\n" );

	return rnf_main;

}

