/***************************************************************************
 *
 * @file	port_656_reg.h
 * @brief	This is Bit field for PORT register.
 *
 * @par		Copyright:
 *			Copyright (C) SEIKO EPSON CORPORATION 2013-2014. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 22 Oct, 2013	1.00
 *				- First revision.
 *			- 27 Feb, 2014	1.0a
 *				- Modify.
 *
 **************************************************************************/

#define  PORT_REG_H__
#ifdef   PORT_REG_H__

#ifdef	__cplusplus
extern "C" {
#endif


/// Px Port Input Data Register.
typedef union PX_IN_REG_TAG {
	unsigned char			reg;
	struct PX_IN_REG_BIT_TAG {
		unsigned short		PXIN0		: 1;
		unsigned short		PXIN1		: 1;
		unsigned short		PXIN2		: 1;
		unsigned short		PXIN3		: 1;
		unsigned short		PXIN4		: 1;
		unsigned short		PXIN5		: 1;
		unsigned short		PXIN6		: 1;
		unsigned short		PXIN7		: 1;
	} bit;
} PX_IN_REG;

/// Px Port Output Data Register.
typedef union PX_OUT_REG_TAG {
	unsigned char			reg;
	struct PX_OUT_REG_BIT_TAG {
		unsigned short		PXOUT0		: 1;
		unsigned short		PXOUT1		: 1;
		unsigned short		PXOUT2		: 1;
		unsigned short		PXOUT3		: 1;
		unsigned short		PXOUT4		: 1;
		unsigned short		PXOUT5		: 1;
		unsigned short		PXOUT6		: 1;
		unsigned short		PXOUT7		: 1;
	} bit;
} PX_OUT_REG;

/// PORT Port Enable Register.
typedef union PX_OEN_REG_TAG {
	unsigned char			reg;
	struct PX_OEN_REG_BIT_TAG {
		unsigned short		PXOEN0		: 1;
		unsigned short		PXOEN1		: 1;
		unsigned short		PXOEN2		: 1;
		unsigned short		PXOEN3		: 1;
		unsigned short		PXOEN4		: 1;
		unsigned short		PXOEN5		: 1;
		unsigned short		PXOEN6		: 1;
		unsigned short		PXOEN7		: 1;
	} bit;
} PX_OEN_REG;

/// Px Port Pull-up Control Register.
typedef union PX_PU_REG_TAG {
	unsigned char			reg;
	struct PX_PU_REG_BIT_TAG {
		unsigned short		PXPU0		: 1;
		unsigned short		PXPU1		: 1;
		unsigned short		PXPU2		: 1;
		unsigned short		PXPU3		: 1;
		unsigned short		PXPU4		: 1;
		unsigned short		PXPU5		: 1;
		unsigned short		PXPU6		: 1;
		unsigned short		PXPU7		: 1;
	} bit;
} PX_PU_REG;

/// Px Port Interrupt Mask Register.
typedef union PX_IMSK_REG_TAG {
	unsigned char			reg;
	struct PX_IMSK_REG_BIT_TAG {
		unsigned short		PXIE0		: 1;
		unsigned short		PXIE1		: 1;
		unsigned short		PXIE2		: 1;
		unsigned short		PXIE3		: 1;
		unsigned short		PXIE4		: 1;
		unsigned short		PXIE5		: 1;
		unsigned short		PXIE6		: 1;
		unsigned short		PXIE7		: 1;
	} bit;
} PX_IMSK_REG;

/// Px Port Interrupt Edge Select Register.
typedef union PX_EDGE_REG_TAG {
	unsigned char			reg;
	struct PX_EDGE_REG_BIT_TAG {
		unsigned short		PXEDGE0		: 1;
		unsigned short		PXEDGE1		: 1;
		unsigned short		PXEDGE2		: 1;
		unsigned short		PXEDGE3		: 1;
		unsigned short		PXEDGE4		: 1;
		unsigned short		PXEDGE5		: 1;
		unsigned short		PXEDGE6		: 1;
		unsigned short		PXEDGE7		: 1;
	} bit;
} PX_EDGE_REG;

/// Px Port Interrupt Flag Register.
/// NOTE : The writing that used the bit field inhibits.
typedef union PX_IFLG_REG_TAG {
	unsigned char			reg;
	struct PX_IFLG_REG_BIT_TAG {
		unsigned short		PXIF0		: 1;
		unsigned short		PXIF1		: 1;
		unsigned short		PXIF2		: 1;
		unsigned short		PXIF3		: 1;
		unsigned short		PXIF4		: 1;
		unsigned short		PXIF5		: 1;
		unsigned short		PXIF6		: 1;
		unsigned short		PXIF7		: 1;
	} bit;
} PX_IFLG_REG;

/// Px Port Chattering Filter Control Register.
typedef union PX_CHAT_REG_TAG {
	unsigned char			reg;
	struct PX_CHAT_REG_BIT_TAG {
		unsigned short		PXCF1		: 3;
		unsigned short		reserved_1	: 1;
		unsigned short		PXCF2		: 3;
		unsigned short		reserved_2	: 1;
	} bit;
} PX_CHAT_REG;

/// Px Port Key-entry Reset Configuration Register.
typedef union PX_KRST_REG_TAG {
	unsigned char			reg;
	struct PX_KRST_REG_BIT_TAG {
		unsigned short		PXKRST		: 2;
		unsigned short		reserved_1	: 6;
	} bit;
} PX_KRST_REG;

/// Px Port Input Enable Register.
/// NOTE : The bit field be the inhibition that uses it,
///		  because 1 is read at the time of read, in the case that there is reserve bit.
typedef union PX_IEN_REG_TAG {
	unsigned char			reg;
	struct PX_IEN_REG_BIT_TAG {
		unsigned short		PXIEN0		: 1;
		unsigned short		PXIEN1		: 1;
		unsigned short		PXIEN2		: 1;
		unsigned short		PXIEN3		: 1;
		unsigned short		PXIEN4		: 1;
		unsigned short		PXIEN5		: 1;
		unsigned short		PXIEN6		: 1;
		unsigned short		PXIEN7		: 1;
	} bit;
} PX_IEN_REG;


#ifdef __cplusplus
}
#endif

#endif	// PORT_656_REG_H__


