/***************************************************************************
 *
 * @file	c17656_reg.h
 * @brief	The definition of C17656 register.
 *
 * @par 	Copyright:
 *			Copyright (C) SEIKO EPSON CORPORATION 2013-2014. All rights reserved.
 *
 * @warning -
 *
 * @par 	History:
 *			- 22 Oct, 2013	1.00
 *				- First revision.
 *			- 27 Feb, 2014	1.0a
 *				- Modify the error in writing.
 *			- 24 Jul, 2014  1.0b
 *				- Modify the error in writing.
 *
 **************************************************************************/

#ifndef C17656_REG_H__
#define C17656_REG_H__

#ifdef	__cplusplus
extern "C" {
#endif

// Include Files
#include "./reg/clg_656_reg.h"
#include "./reg/ct_reg.h"
#include "./reg/flashc_reg.h"
#include "./reg/itc_reg.h"
#include "./reg/lcd_reg.h"
#include "./reg/misc_reg.h"
#include "./reg/mux_reg.h"
#include "./reg/port_656_reg.h"
#include "./reg/rfc_reg.h"
#include "./reg/rtc_reg.h"
#include "./reg/snd_reg.h"
#include "./reg/spi_reg.h"
#include "./reg/svd_reg.h"
#include "./reg/t16a2_reg.h"
#include "./reg/t8_reg.h"
#include "./reg/uart_reg.h"
#include "./reg/vd1_reg.h"
#include "./reg/wdt_reg.h"


// Register Base Address
#define BASE_ADDR						( 0x4000 )	///< base address

#define MISC_REG_BASE_ADDR				( 0x4020 )	///< MISC 8bit device base address
#define UART_REG_BASE_ADDR				( 0x4100 )	///< UART base address
#define T8_REG_BASE_ADDR				( 0x4240 )	///< T8 base address
#define ITC_REG_BASE_ADDR				( 0x4306 )	///< ITC base address
#define SPI_REG_BASE_ADDR				( 0x4320 )	///< SPI base address
#define CT_REG_BASE_ADDR				( 0x5000 )	///< CT base address
#define WDT_REG_BASE_ADDR				( 0x5040 )	///< WDT base address
#define CLG_REG_BASE_ADDR				( 0x5060 )	///< CLG base address
#define LCD_REG_BASE_ADDR				( 0x5070 )	///< LCD base address
#define SVD_REG_BASE_ADDR				( 0x5100 )	///< SVD base address
#define VD1_REG_BASE_ADDR				( 0x5120 )	///< VD1 base address
#define SND_REG_BASE_ADDR				( 0x5180 )	///< SND base address
#define PORT_REG_BASE_ADDR				( 0x5200 )	///< PORT base address
#define MUX_REG_BASE_ADDR				( 0x52a0 )	///< PORT MUX base address
#define MISC2_REG_BASE_ADDR 			( 0x5322 )	///< MISC 16bit device base address
#define RFC_REG_BASE_ADDR				( 0x53A0 )	///< RFC base Address.
#define T16A2_REG_BASE_ADDR 			( 0x5400 )	///< T16A2 base address
#define FLASHC_REG_BASE_ADDR			( 0x54B0 )	///< FLASHC base address
#define RTC_REG_BASE_ADDR				( 0x56C0 )	///< RTC base address


/* ----- C17656 Registers ----- */

/********************/
/* ----- MISC ----- */
/********************/
// Debug Mode Control Register1
#define MISC_DMODE1 					(*((volatile MISC_DMODE1_REG *)(MISC_REG_BASE_ADDR + 0x00))).reg
#define MISC_DMODE1_DBRUN1				(*((volatile MISC_DMODE1_REG *)(MISC_REG_BASE_ADDR + 0x00))).bit.DBRUN1 	///< PCLK peripheral control in debug mode

// Debug Mode Control Register2
#define MISC_DMODE2 					(*((volatile MISC_DMODE2_REG *)(MISC2_REG_BASE_ADDR + 0x00))).reg
#define MISC_DMODE2_DBRUN2				MISC_DMODE2 																///< expect PCLK peripheral control in debug mode

// MISC ProtectRegister
#define MISC_PROT						(*((volatile MISC_PROT_REG *)(MISC2_REG_BASE_ADDR + 0x02))).reg 			///< MISC Register write protect

// IRAM Size Select Register
#define MISC_IRAMSZ 					(*((volatile MISC_IRAMSZ_REG *)(MISC2_REG_BASE_ADDR + 0x04))).reg
#define MISC_IRAMSZ_DBADR				(*((volatile MISC_IRAMSZ_REG *)(MISC2_REG_BASE_ADDR + 0x04))).byte_reg[1]	///< Debug base address select
#define MISC_IRAMSZ_IRAMACTSZ			(*((volatile MISC_IRAMSZ_REG *)(MISC2_REG_BASE_ADDR + 0x04))).bit.IRAMACTSZ ///< IRAM actual size register
#define MISC_IRAMSZ_IRAMSZ				(*((volatile MISC_IRAMSZ_REG *)(MISC2_REG_BASE_ADDR + 0x04))).bit.IRAMSZ	///< IRAM size select

// Vector Table Address Low Register
// Vector Table Address High Register
#define MISC_TTBR						(*((volatile MISC_TTBR_REG *)(MISC2_REG_BASE_ADDR + 0x06))).reg
#define MISC_TTBR_0_23					MISC_TTBR																	///< Vector table base address [23:0]

// MISC PSR Register
#define MISC_PSR						(*((volatile MISC_PSR_REG *)(MISC2_REG_BASE_ADDR + 0x0a))).reg
#define MISC_PSR_PSRIL					(*((volatile MISC_PSR_REG *)(MISC2_REG_BASE_ADDR + 0x0a))).bit.PSRIL		///< PSR Interrupt level (IL) bits
#define MISC_PSR_PSRIE					(*((volatile MISC_PSR_REG *)(MISC2_REG_BASE_ADDR + 0x0a))).bit.PSRIE		///< PSR Interrupt enable (IE) bits
#define MISC_PSR_PSRC					(*((volatile MISC_PSR_REG *)(MISC2_REG_BASE_ADDR + 0x0a))).bit.PSRC 		///< PSR carry (C) flag
#define MISC_PSR_PSRV					(*((volatile MISC_PSR_REG *)(MISC2_REG_BASE_ADDR + 0x0a))).bit.PSRV 		///< PSR overflow (V) flag
#define MISC_PSR_PSRZ					(*((volatile MISC_PSR_REG *)(MISC2_REG_BASE_ADDR + 0x0a))).bit.PSRZ 		///< PSR zero (Z) flag
#define MISC_PSR_PSRN					(*((volatile MISC_PSR_REG *)(MISC2_REG_BASE_ADDR + 0x0a))).bit.PSRN 		///< PSR negative (N) flag


/***********************************************
 ****** The Definition of Clock Generator ******
 ****** [CLG]							  ******
 ***********************************************/
// Clock Source Select Register
#define CLG_SRC 						(*((volatile CLG_SRC_REG *)(CLG_REG_BASE_ADDR + 0x00))).reg
#define CLG_SRC_OSC3BFSEL				(*((volatile CLG_SRC_REG *)(CLG_REG_BASE_ADDR + 0x00))).bit.OSC3BFSEL		///< OSC3B frequency select
#define CLG_SRC_CLKSRC					(*((volatile CLG_SRC_REG *)(CLG_REG_BASE_ADDR + 0x00))).bit.CLKSRC			///< System clock source select

// Oscillation Control Register
#define CLG_CTL 						(*((volatile CLG_CTL_REG *)(CLG_REG_BASE_ADDR + 0x01))).reg
#define CLG_CTL_OSC3BEN 				(*((volatile CLG_CTL_REG *)(CLG_REG_BASE_ADDR + 0x01))).bit.OSC3BEN 		///< OSC3B enable
#define CLG_CTL_OSC1EN					(*((volatile CLG_CTL_REG *)(CLG_REG_BASE_ADDR + 0x01))).bit.OSC1EN			///< OSC1 enable

// FOUTA Control Register
#define CLG_FOUTA						(*((volatile CLG_FOUTX_REG *)(CLG_REG_BASE_ADDR + 0x04))).reg
#define CLG_FOUTA_FOUTAD				(*((volatile CLG_FOUTX_REG *)(CLG_REG_BASE_ADDR + 0x04))).bit.FOUTXD		///< FOUTA clock division ratio select
#define CLG_FOUTA_FOUTASRC				(*((volatile CLG_FOUTX_REG *)(CLG_REG_BASE_ADDR + 0x04))).bit.FOUTXSRC		///< FOUTA clock source select
#define CLG_FOUTA_FOUTAE				(*((volatile CLG_FOUTX_REG *)(CLG_REG_BASE_ADDR + 0x04))).bit.FOUTXE		///< FOUTA output enable

// FOUTB Control Register
#define CLG_FOUTB						(*((volatile CLG_FOUTX_REG *)(CLG_REG_BASE_ADDR + 0x05))).reg
#define CLG_FOUTB_FOUTBD				(*((volatile CLG_FOUTX_REG *)(CLG_REG_BASE_ADDR + 0x05))).bit.FOUTXD		///< FOUTB clock division ratio select
#define CLG_FOUTB_FOUTBSRC				(*((volatile CLG_FOUTX_REG *)(CLG_REG_BASE_ADDR + 0x05))).bit.FOUTXSRC		///< FOUTB clock source select
#define CLG_FOUTB_FOUTBE				(*((volatile CLG_FOUTX_REG *)(CLG_REG_BASE_ADDR + 0x05))).bit.FOUTXE		///< FOUTB output enable

// Oscillation Stabilization Wait Control Register
#define CLG_WAIT						(*((volatile CLG_WAIT_REG *)(CLG_REG_BASE_ADDR + 0x1d))).reg
#define CLG_WAIT_OSC3BWT				(*((volatile CLG_WAIT_REG *)(CLG_REG_BASE_ADDR + 0x1d))).bit.OSC3BWT		///< OSC3B stabilization wait cycle select
#define CLG_WAIT_OSC1AWT				(*((volatile CLG_WAIT_REG *)(CLG_REG_BASE_ADDR + 0x1d))).bit.OSC1AWT		///< OSC1A stabilization wait cycle enable

// PCLK Control Register
#define CLG_PCLK						(*((volatile CLG_PCLK_REG *)(CLG_REG_BASE_ADDR + 0x20))).reg
#define CLG_PCLK_PCKEN					CLG_PCLK																	///< PCLK enable

// CCLK Control Register
#define CLG_CCLK						(*((volatile CLG_CCLK_REG *)(CLG_REG_BASE_ADDR + 0x21))).reg
#define CLG_CCLK_CCLKGR 				CLG_CCLK																	///< CCLK clock gear ratio select


/**********************/
/* ----- FLASHC ----- */
/**********************/
// FLASHC Flash Read Cycle Register
#define FLASHC_WAIT 					(*((volatile FLASHC_WAIT_REG *)(FLASHC_REG_BASE_ADDR + 0x00))).reg
#define FLASHC_WAIT_RDWAIT				FLASHC_WAIT 																///< Flash read wait cycle


/***********************************************
 ****** The Definition of Port MUX			****
 ****** [Px]								****
 ***********************************************/
// P0 Port Function Select Register
#define P00_03PMUX						(*((volatile PX0_X3PMUX_REG *)(MUX_REG_BASE_ADDR + 0x00))).reg
#define P00_03PMUX_P03MUX				(*((volatile PX0_X3PMUX_REG *)(MUX_REG_BASE_ADDR + 0x00))).bit.PX3MUX	///< P03 port function select
#define P00_03PMUX_P02MUX				(*((volatile PX0_X3PMUX_REG *)(MUX_REG_BASE_ADDR + 0x00))).bit.PX2MUX	///< P02 port function select
#define P00_03PMUX_P01MUX				(*((volatile PX0_X3PMUX_REG *)(MUX_REG_BASE_ADDR + 0x00))).bit.PX1MUX	///< P01 port function select
#define P00_03PMUX_P00MUX				(*((volatile PX0_X3PMUX_REG *)(MUX_REG_BASE_ADDR + 0x00))).bit.PX0MUX	///< P00 port function select

// P0 Port Function Select Register
#define P04_07PMUX						(*((volatile PX4_X7PMUX_REG *)(MUX_REG_BASE_ADDR + 0x01))).reg
#define P04_07PMUX_P07MUX				(*((volatile PX4_X7PMUX_REG *)(MUX_REG_BASE_ADDR + 0x01))).bit.PX7MUX	///< P07 port function select
#define P04_07PMUX_P06MUX				(*((volatile PX4_X7PMUX_REG *)(MUX_REG_BASE_ADDR + 0x01))).bit.PX6MUX	///< P06 port function select
#define P04_07PMUX_P05MUX				(*((volatile PX4_X7PMUX_REG *)(MUX_REG_BASE_ADDR + 0x01))).bit.PX5MUX	///< P05 port function select
#define P04_07PMUX_P04MUX				(*((volatile PX4_X7PMUX_REG *)(MUX_REG_BASE_ADDR + 0x01))).bit.PX4MUX	///< P04 port function select

// P1 Port Function Select Register
#define P10_13PMUX						(*((volatile PX0_X3PMUX_REG *)(MUX_REG_BASE_ADDR + 0x02))).reg
#define P10_13PMUX_P13MUX				(*((volatile PX0_X3PMUX_REG *)(MUX_REG_BASE_ADDR + 0x02))).bit.PX3MUX	///< P13 port function select
#define P10_13PMUX_P12MUX				(*((volatile PX0_X3PMUX_REG *)(MUX_REG_BASE_ADDR + 0x02))).bit.PX2MUX	///< P12 port function select
#define P10_13PMUX_P11MUX				(*((volatile PX0_X3PMUX_REG *)(MUX_REG_BASE_ADDR + 0x02))).bit.PX1MUX	///< P11 port function select
#define P10_13PMUX_P10MUX				(*((volatile PX0_X3PMUX_REG *)(MUX_REG_BASE_ADDR + 0x02))).bit.PX0MUX	///< P10 port function select

// P1 Port Function Select Register
#define P14_17PMUX						(*((volatile PX4_X7PMUX_REG *)(MUX_REG_BASE_ADDR + 0x03))).reg
#define P14_17PMUX_P17MUX				(*((volatile PX4_X7PMUX_REG *)(MUX_REG_BASE_ADDR + 0x03))).bit.PX7MUX	///< P17 port function select
#define P14_17PMUX_P16MUX				(*((volatile PX4_X7PMUX_REG *)(MUX_REG_BASE_ADDR + 0x03))).bit.PX6MUX	///< P16 port function select
#define P14_17PMUX_P15MUX				(*((volatile PX4_X7PMUX_REG *)(MUX_REG_BASE_ADDR + 0x03))).bit.PX5MUX	///< P15 port function select
#define P14_17PMUX_P14MUX				(*((volatile PX4_X7PMUX_REG *)(MUX_REG_BASE_ADDR + 0x03))).bit.PX4MUX	///< P14 port function select

// P2 Port Function Select Register
#define P23PMUX 						(*((volatile PX0_X3PMUX_REG *)(MUX_REG_BASE_ADDR + 0x04))).reg
#define P23PMUX_P23MUX					(*((volatile PX0_X3PMUX_REG *)(MUX_REG_BASE_ADDR + 0x04))).bit.PX3MUX	///< P23 port function select


/***********************************************
 ****** The Definition of ClockTimer ***********
 ****** [CT]						 ***********
 ***********************************************/
// Clock Timer Control Register
#define CT_CTL							(*((volatile CT_CTL_REG *)(CT_REG_BASE_ADDR + 0x00))).reg
#define CT_CTL_CTRST					(*((volatile CT_CTL_REG *)(CT_REG_BASE_ADDR + 0x00))).bit.CTRST 			///< Clock timer reset
#define CT_CTL_CTRUN					(*((volatile CT_CTL_REG *)(CT_REG_BASE_ADDR + 0x00))).bit.CTRUN 			///< Clock timer run/stop control

// Clock Timer Counter Register
#define CT_CNT							(*((volatile CT_CNT_REG *)(CT_REG_BASE_ADDR + 0x01))).reg
#define CT_CNT_CTCNT					CT_CNT																		///< Clock timer counter value

// Clock Timer Interrupt Mask Register
#define CT_IMSK 						(*((volatile CT_IMSK_REG *)(CT_REG_BASE_ADDR + 0x02))).reg
#define CT_IMSK_CTIE32					(*((volatile CT_IMSK_REG *)(CT_REG_BASE_ADDR + 0x02))).bit.CTIE32			///< 32 Hz interrupt enable
#define CT_IMSK_CTIE8					(*((volatile CT_IMSK_REG *)(CT_REG_BASE_ADDR + 0x02))).bit.CTIE8			///< 8 Hz interrupt enable
#define CT_IMSK_CTIE2					(*((volatile CT_IMSK_REG *)(CT_REG_BASE_ADDR + 0x02))).bit.CTIE2			///< 2 Hz interrupt enable
#define CT_IMSK_CTIE1					(*((volatile CT_IMSK_REG *)(CT_REG_BASE_ADDR + 0x02))).bit.CTIE1			///< 1 Hz interrupt enable

// Clock Timer Interrupt Flag Register
#define CT_IFLG 						(*((volatile CT_IFLG_REG *)(CT_REG_BASE_ADDR + 0x03))).reg
#define CT_IFLG_CTIF32					(*((volatile CT_IFLG_REG *)(CT_REG_BASE_ADDR + 0x03))).bit.CTIF32			///< 32 Hz interrupt flag  (read only)
#define CT_IFLG_CTIF8					(*((volatile CT_IFLG_REG *)(CT_REG_BASE_ADDR + 0x03))).bit.CTIF8			///< 8 Hz interrupt flag  (read only)
#define CT_IFLG_CTIF2					(*((volatile CT_IFLG_REG *)(CT_REG_BASE_ADDR + 0x03))).bit.CTIF2			///< 2 Hz interrupt flag  (read only)
#define CT_IFLG_CTIF1					(*((volatile CT_IFLG_REG *)(CT_REG_BASE_ADDR + 0x03))).bit.CTIF1			///< 1 Hz interrupt flag  (read only)


/***********************************************
 ****** The Definition of Interrupt Controller *
 ****** [ITC]								   *
 ***********************************************/
// Interrupt Level Setup Register 0
#define ITC_LV0 						(*((volatile ITC_LVX_REG *)(ITC_REG_BASE_ADDR + 0x00))).reg
#define ITC_LV0_ILV0					ITC_LV0 																	///< P0 interrupt level

// Interrupt Level Setup Register 1
#define ITC_LV1 						(*((volatile ITC_LVX_REG *)(ITC_REG_BASE_ADDR + 0x02))).reg
#define ITC_LV1_ILV3					(*((volatile ITC_LVX_REG *)(ITC_REG_BASE_ADDR + 0x02))).byte_reg[1] 		///< CT interrupt level

// Interrupt Level Setup Register 2
#define ITC_LV2 						(*((volatile ITC_LVX_REG *)(ITC_REG_BASE_ADDR + 0x04))).reg
#define ITC_LV2_ILV4					ITC_LV2 																	///< RTC interrupt level

// Interrupt Level Setup Register 3
#define ITC_LV3 						(*((volatile ITC_LVX_REG *)(ITC_REG_BASE_ADDR + 0x06))).reg
#define ITC_LV3_ILV7					(*((volatile ITC_LVX_REG *)(ITC_REG_BASE_ADDR + 0x06))).byte_reg[1] 		///< T16A2 interrupt level
#define ITC_LV3_ILV6					(*((volatile ITC_LVX_REG *)(ITC_REG_BASE_ADDR + 0x06))).byte_reg[0] 		///< LCD interrupt level

// Interrupt Level Setup Register 5
#define ITC_LV5 						(*((volatile ITC_LVX_REG *)(ITC_REG_BASE_ADDR + 0x0a))).reg
#define ITC_LV5_ILV10					ITC_LV5 																	///< T8 Ch.0 interrupt level

// Interrupt Level Setup Register 6
#define ITC_LV6 						(*((volatile ITC_LVX_REG *)(ITC_REG_BASE_ADDR + 0x0c))).reg
#define ITC_LV6_ILV12					ITC_LV6 																	///< UART Ch.0 interrupt level

// Interrupt Level Setup Register 7
#define ITC_LV7 						(*((volatile ITC_LVX_REG *)(ITC_REG_BASE_ADDR + 0x0e))).reg
#define ITC_LV7_ILV14					ITC_LV7 																	///< SPI Ch.0 interrupt level

// Interrupt Level Setup Register 8
#define ITC_LV8 						(*((volatile ITC_LVX_REG *)(ITC_REG_BASE_ADDR + 0x10))).reg
#define ITC_LV8_ILV17					(*((volatile ITC_LVX_REG *)(ITC_REG_BASE_ADDR + 0x10))).byte_reg[1] 		///< RFC interrupt level

// Interrupt Level Setup Register 9
#define ITC_LV9 						(*((volatile ITC_LVX_REG *)(ITC_REG_BASE_ADDR + 0x12))).reg
#define ITC_LV9_ILV18					ITC_LV9 																	///< SVD interrupt level


/***********************************************
 ****** The Definition of P Port			****
 ****** [Px]								****
 ***********************************************/
// Px Port Input Data Register
#define P0_IN							(*((volatile PX_IN_REG *)(PORT_REG_BASE_ADDR + 0x00))).reg
#define P0_IN_P0IN						P0_IN																		///< P0[7:0] port input data
#define P0_IN_P0IN0 					(*((volatile PX_IN_REG *)(PORT_REG_BASE_ADDR + 0x00))).bit.PXIN0
#define P0_IN_P0IN1 					(*((volatile PX_IN_REG *)(PORT_REG_BASE_ADDR + 0x00))).bit.PXIN1
#define P0_IN_P0IN2 					(*((volatile PX_IN_REG *)(PORT_REG_BASE_ADDR + 0x00))).bit.PXIN2
#define P0_IN_P0IN3 					(*((volatile PX_IN_REG *)(PORT_REG_BASE_ADDR + 0x00))).bit.PXIN3
#define P0_IN_P0IN4 					(*((volatile PX_IN_REG *)(PORT_REG_BASE_ADDR + 0x00))).bit.PXIN4
#define P0_IN_P0IN5 					(*((volatile PX_IN_REG *)(PORT_REG_BASE_ADDR + 0x00))).bit.PXIN5
#define P0_IN_P0IN6 					(*((volatile PX_IN_REG *)(PORT_REG_BASE_ADDR + 0x00))).bit.PXIN6
#define P0_IN_P0IN7 					(*((volatile PX_IN_REG *)(PORT_REG_BASE_ADDR + 0x00))).bit.PXIN7

#define P1_IN							(*((volatile PX_IN_REG *)(PORT_REG_BASE_ADDR + 0x10))).reg
#define P1_IN_P1IN						P1_IN																		///< P10,P1[7:2] port input data
#define P1_IN_P1IN0 					(*((volatile PX_IN_REG *)(PORT_REG_BASE_ADDR + 0x10))).bit.PXIN0
#define P1_IN_P1IN2 					(*((volatile PX_IN_REG *)(PORT_REG_BASE_ADDR + 0x10))).bit.PXIN2
#define P1_IN_P1IN3 					(*((volatile PX_IN_REG *)(PORT_REG_BASE_ADDR + 0x10))).bit.PXIN3
#define P1_IN_P1IN4 					(*((volatile PX_IN_REG *)(PORT_REG_BASE_ADDR + 0x10))).bit.PXIN4
#define P1_IN_P1IN5 					(*((volatile PX_IN_REG *)(PORT_REG_BASE_ADDR + 0x10))).bit.PXIN5
#define P1_IN_P1IN6 					(*((volatile PX_IN_REG *)(PORT_REG_BASE_ADDR + 0x10))).bit.PXIN6
#define P1_IN_P1IN7 					(*((volatile PX_IN_REG *)(PORT_REG_BASE_ADDR + 0x10))).bit.PXIN7

#define P2_IN							(*((volatile PX_IN_REG *)(PORT_REG_BASE_ADDR + 0x20))).reg
#define P2_IN_P2IN						P2_IN																		///< P2[7:0] port input data
#define P2_IN_P2IN0 					(*((volatile PX_IN_REG *)(PORT_REG_BASE_ADDR + 0x20))).bit.PXIN0
#define P2_IN_P2IN1 					(*((volatile PX_IN_REG *)(PORT_REG_BASE_ADDR + 0x20))).bit.PXIN1
#define P2_IN_P2IN2 					(*((volatile PX_IN_REG *)(PORT_REG_BASE_ADDR + 0x20))).bit.PXIN2
#define P2_IN_P2IN3 					(*((volatile PX_IN_REG *)(PORT_REG_BASE_ADDR + 0x20))).bit.PXIN3

// Px Port Output Data Register
#define P0_OUT							(*((volatile PX_OUT_REG *)(PORT_REG_BASE_ADDR + 0x01))).reg
#define P0_OUT_P0OUT					P0_OUT																		///< P0[7:0] port output data
#define P0_OUT_P0OUT0					(*((volatile PX_OUT_REG *)(PORT_REG_BASE_ADDR + 0x01))).bit.PXOUT0
#define P0_OUT_P0OUT1					(*((volatile PX_OUT_REG *)(PORT_REG_BASE_ADDR + 0x01))).bit.PXOUT1
#define P0_OUT_P0OUT2					(*((volatile PX_OUT_REG *)(PORT_REG_BASE_ADDR + 0x01))).bit.PXOUT2
#define P0_OUT_P0OUT3					(*((volatile PX_OUT_REG *)(PORT_REG_BASE_ADDR + 0x01))).bit.PXOUT3
#define P0_OUT_P0OUT4					(*((volatile PX_OUT_REG *)(PORT_REG_BASE_ADDR + 0x01))).bit.PXOUT4
#define P0_OUT_P0OUT5					(*((volatile PX_OUT_REG *)(PORT_REG_BASE_ADDR + 0x01))).bit.PXOUT5
#define P0_OUT_P0OUT6					(*((volatile PX_OUT_REG *)(PORT_REG_BASE_ADDR + 0x01))).bit.PXOUT6
#define P0_OUT_P0OUT7					(*((volatile PX_OUT_REG *)(PORT_REG_BASE_ADDR + 0x01))).bit.PXOUT7

#define P1_OUT							(*((volatile PX_OUT_REG *)(PORT_REG_BASE_ADDR + 0x11))).reg
#define P1_OUT_P1OUT					P1_OUT																		///< P1[7:0] port output data
#define P1_OUT_P1OUT0					(*((volatile PX_OUT_REG *)(PORT_REG_BASE_ADDR + 0x11))).bit.PXOUT0
#define P1_OUT_P1OUT1					(*((volatile PX_OUT_REG *)(PORT_REG_BASE_ADDR + 0x11))).bit.PXOUT1
#define P1_OUT_P1OUT2					(*((volatile PX_OUT_REG *)(PORT_REG_BASE_ADDR + 0x11))).bit.PXOUT2
#define P1_OUT_P1OUT3					(*((volatile PX_OUT_REG *)(PORT_REG_BASE_ADDR + 0x11))).bit.PXOUT3
#define P1_OUT_P1OUT4					(*((volatile PX_OUT_REG *)(PORT_REG_BASE_ADDR + 0x11))).bit.PXOUT4
#define P1_OUT_P1OUT5					(*((volatile PX_OUT_REG *)(PORT_REG_BASE_ADDR + 0x11))).bit.PXOUT5
#define P1_OUT_P1OUT6					(*((volatile PX_OUT_REG *)(PORT_REG_BASE_ADDR + 0x11))).bit.PXOUT6
#define P1_OUT_P1OUT7					(*((volatile PX_OUT_REG *)(PORT_REG_BASE_ADDR + 0x11))).bit.PXOUT7

#define P2_OUT							(*((volatile PX_OUT_REG *)(PORT_REG_BASE_ADDR + 0x21))).reg
#define P2_OUT_P2OUT					P2_OUT																		///< P2[7:0] port output data
#define P2_OUT_P2OUT0					(*((volatile PX_OUT_REG *)(PORT_REG_BASE_ADDR + 0x21))).bit.PXOUT0
#define P2_OUT_P2OUT1					(*((volatile PX_OUT_REG *)(PORT_REG_BASE_ADDR + 0x21))).bit.PXOUT1
#define P2_OUT_P2OUT2					(*((volatile PX_OUT_REG *)(PORT_REG_BASE_ADDR + 0x21))).bit.PXOUT2
#define P2_OUT_P2OUT3					(*((volatile PX_OUT_REG *)(PORT_REG_BASE_ADDR + 0x21))).bit.PXOUT3

// Px Port Output Enable Register
#define P0_OEN							(*((volatile PX_OEN_REG *)(PORT_REG_BASE_ADDR + 0x02))).reg
#define P0_OEN_P0OEN					P0_OEN																		///< P0[7:0] port output enable / disable
#define P0_OEN_P0OEN0					(*((volatile PX_OEN_REG *)(PORT_REG_BASE_ADDR + 0x02))).bit.PXOEN0
#define P0_OEN_P0OEN1					(*((volatile PX_OEN_REG *)(PORT_REG_BASE_ADDR + 0x02))).bit.PXOEN1
#define P0_OEN_P0OEN2					(*((volatile PX_OEN_REG *)(PORT_REG_BASE_ADDR + 0x02))).bit.PXOEN2
#define P0_OEN_P0OEN3					(*((volatile PX_OEN_REG *)(PORT_REG_BASE_ADDR + 0x02))).bit.PXOEN3
#define P0_OEN_P0OEN4					(*((volatile PX_OEN_REG *)(PORT_REG_BASE_ADDR + 0x02))).bit.PXOEN4
#define P0_OEN_P0OEN5					(*((volatile PX_OEN_REG *)(PORT_REG_BASE_ADDR + 0x02))).bit.PXOEN5
#define P0_OEN_P0OEN6					(*((volatile PX_OEN_REG *)(PORT_REG_BASE_ADDR + 0x02))).bit.PXOEN6
#define P0_OEN_P0OEN7					(*((volatile PX_OEN_REG *)(PORT_REG_BASE_ADDR + 0x02))).bit.PXOEN7

#define P1_OEN							(*((volatile PX_OEN_REG *)(PORT_REG_BASE_ADDR + 0x12))).reg
#define P1_OEN_P1OEN					P1_OEN																		///< P1[7:0] port output enable / disable
#define P1_OEN_P1OEN0					(*((volatile PX_OEN_REG *)(PORT_REG_BASE_ADDR + 0x12))).bit.PXOEN0
#define P1_OEN_P1OEN1					(*((volatile PX_OEN_REG *)(PORT_REG_BASE_ADDR + 0x12))).bit.PXOEN1
#define P1_OEN_P1OEN2					(*((volatile PX_OEN_REG *)(PORT_REG_BASE_ADDR + 0x12))).bit.PXOEN2
#define P1_OEN_P1OEN3					(*((volatile PX_OEN_REG *)(PORT_REG_BASE_ADDR + 0x12))).bit.PXOEN3
#define P1_OEN_P1OEN4					(*((volatile PX_OEN_REG *)(PORT_REG_BASE_ADDR + 0x12))).bit.PXOEN4
#define P1_OEN_P1OEN5					(*((volatile PX_OEN_REG *)(PORT_REG_BASE_ADDR + 0x12))).bit.PXOEN5
#define P1_OEN_P1OEN6					(*((volatile PX_OEN_REG *)(PORT_REG_BASE_ADDR + 0x12))).bit.PXOEN6
#define P1_OEN_P1OEN7					(*((volatile PX_OEN_REG *)(PORT_REG_BASE_ADDR + 0x12))).bit.PXOEN7

#define P2_OEN							(*((volatile PX_OEN_REG *)(PORT_REG_BASE_ADDR + 0x22))).reg
#define P2_OEN_P2OEN					P2_OEN																		///< P2[7:0] port output enable / disable
#define P2_OEN_P2OEN0					(*((volatile PX_OEN_REG *)(PORT_REG_BASE_ADDR + 0x22))).bit.PXOEN0
#define P2_OEN_P2OEN1					(*((volatile PX_OEN_REG *)(PORT_REG_BASE_ADDR + 0x22))).bit.PXOEN1
#define P2_OEN_P2OEN2					(*((volatile PX_OEN_REG *)(PORT_REG_BASE_ADDR + 0x22))).bit.PXOEN2
#define P2_OEN_P2OEN3					(*((volatile PX_OEN_REG *)(PORT_REG_BASE_ADDR + 0x22))).bit.PXOEN3

// Px Port Pull-up Control Register
// NOTE : The bit field be the inhibition that uses it,
//		  because 1 is read at the time of read, in the case that there is reserve bit.
#define P0_PU							(*((volatile PX_PU_REG *)(PORT_REG_BASE_ADDR + 0x03))).reg
#define P0_PU_P0PU						P0_PU																		///< P0[7:0] port pull-up enable
#define P0_PU_P0PU0 					(*((volatile PX_PU_REG *)(PORT_REG_BASE_ADDR + 0x03))).bit.PXPU0
#define P0_PU_P0PU1 					(*((volatile PX_PU_REG *)(PORT_REG_BASE_ADDR + 0x03))).bit.PXPU1
#define P0_PU_P0PU2 					(*((volatile PX_PU_REG *)(PORT_REG_BASE_ADDR + 0x03))).bit.PXPU2
#define P0_PU_P0PU3 					(*((volatile PX_PU_REG *)(PORT_REG_BASE_ADDR + 0x03))).bit.PXPU3
#define P0_PU_P0PU4 					(*((volatile PX_PU_REG *)(PORT_REG_BASE_ADDR + 0x03))).bit.PXPU4
#define P0_PU_P0PU5 					(*((volatile PX_PU_REG *)(PORT_REG_BASE_ADDR + 0x03))).bit.PXPU5
#define P0_PU_P0PU6 					(*((volatile PX_PU_REG *)(PORT_REG_BASE_ADDR + 0x03))).bit.PXPU6
#define P0_PU_P0PU7 					(*((volatile PX_PU_REG *)(PORT_REG_BASE_ADDR + 0x03))).bit.PXPU7

#define P1_PU							(*((volatile PX_PU_REG *)(PORT_REG_BASE_ADDR + 0x13))).reg
#define P1_PU_P1PU						P1_PU																		///< P1[7:0] port pull-up enable
#define P1_PU_P1PU0 					(*((volatile PX_PU_REG *)(PORT_REG_BASE_ADDR + 0x13))).bit.PXPU0
#define P1_PU_P1PU1 					(*((volatile PX_PU_REG *)(PORT_REG_BASE_ADDR + 0x13))).bit.PXPU1
#define P1_PU_P1PU2 					(*((volatile PX_PU_REG *)(PORT_REG_BASE_ADDR + 0x13))).bit.PXPU2
#define P1_PU_P1PU3 					(*((volatile PX_PU_REG *)(PORT_REG_BASE_ADDR + 0x13))).bit.PXPU3
#define P1_PU_P1PU4 					(*((volatile PX_PU_REG *)(PORT_REG_BASE_ADDR + 0x13))).bit.PXPU4
#define P1_PU_P1PU5 					(*((volatile PX_PU_REG *)(PORT_REG_BASE_ADDR + 0x13))).bit.PXPU5
#define P1_PU_P1PU6 					(*((volatile PX_PU_REG *)(PORT_REG_BASE_ADDR + 0x13))).bit.PXPU6
#define P1_PU_P1PU7 					(*((volatile PX_PU_REG *)(PORT_REG_BASE_ADDR + 0x13))).bit.PXPU7

#define P2_PU							(*((volatile PX_PU_REG *)(PORT_REG_BASE_ADDR + 0x23))).reg
#define P2_PU_P2PU						P2_PU																		///< P2[7:0] port pull-up enable
#define P2_PU_P2PU0 					(*((volatile PX_PU_REG *)(PORT_REG_BASE_ADDR + 0x23))).bit.PXPU0
#define P2_PU_P2PU1 					(*((volatile PX_PU_REG *)(PORT_REG_BASE_ADDR + 0x23))).bit.PXPU1
#define P2_PU_P2PU2 					(*((volatile PX_PU_REG *)(PORT_REG_BASE_ADDR + 0x23))).bit.PXPU2
#define P2_PU_P2PU3 					(*((volatile PX_PU_REG *)(PORT_REG_BASE_ADDR + 0x23))).bit.PXPU3

// Px Port Interrupt Mask Register
#define P0_IMSK 						(*((volatile PX_IMSK_REG *)(PORT_REG_BASE_ADDR + 0x05))).reg
#define P0_IMSK_P0IE					P0_IMSK 																	///< P0[7:0] port interrupt enable
#define P0_IMSK_P0IE0					(*((volatile PX_IMSK_REG *)(PORT_REG_BASE_ADDR + 0x05))).bit.PXIE0
#define P0_IMSK_P0IE1					(*((volatile PX_IMSK_REG *)(PORT_REG_BASE_ADDR + 0x05))).bit.PXIE1
#define P0_IMSK_P0IE2					(*((volatile PX_IMSK_REG *)(PORT_REG_BASE_ADDR + 0x05))).bit.PXIE2
#define P0_IMSK_P0IE3					(*((volatile PX_IMSK_REG *)(PORT_REG_BASE_ADDR + 0x05))).bit.PXIE3
#define P0_IMSK_P0IE4					(*((volatile PX_IMSK_REG *)(PORT_REG_BASE_ADDR + 0x05))).bit.PXIE4
#define P0_IMSK_P0IE5					(*((volatile PX_IMSK_REG *)(PORT_REG_BASE_ADDR + 0x05))).bit.PXIE5
#define P0_IMSK_P0IE6					(*((volatile PX_IMSK_REG *)(PORT_REG_BASE_ADDR + 0x05))).bit.PXIE6
#define P0_IMSK_P0IE7					(*((volatile PX_IMSK_REG *)(PORT_REG_BASE_ADDR + 0x05))).bit.PXIE7

// Px Port Interrupt Edge Select Register
#define P0_EDGE 						(*((volatile PX_EDGE_REG *)(PORT_REG_BASE_ADDR + 0x06))).reg
#define P0_EDGE_P0EDGE					P0_EDGE 																	///< P0[7:0] port interrupt edge select
#define P0_EDGE_P0EDGE0 				(*((volatile PX_EDGE_REG *)(PORT_REG_BASE_ADDR + 0x06))).bit.PXEDGE0
#define P0_EDGE_P0EDGE1 				(*((volatile PX_EDGE_REG *)(PORT_REG_BASE_ADDR + 0x06))).bit.PXEDGE1
#define P0_EDGE_P0EDGE2 				(*((volatile PX_EDGE_REG *)(PORT_REG_BASE_ADDR + 0x06))).bit.PXEDGE2
#define P0_EDGE_P0EDGE3 				(*((volatile PX_EDGE_REG *)(PORT_REG_BASE_ADDR + 0x06))).bit.PXEDGE3
#define P0_EDGE_P0EDGE4 				(*((volatile PX_EDGE_REG *)(PORT_REG_BASE_ADDR + 0x06))).bit.PXEDGE4
#define P0_EDGE_P0EDGE5 				(*((volatile PX_EDGE_REG *)(PORT_REG_BASE_ADDR + 0x06))).bit.PXEDGE5
#define P0_EDGE_P0EDGE6 				(*((volatile PX_EDGE_REG *)(PORT_REG_BASE_ADDR + 0x06))).bit.PXEDGE6
#define P0_EDGE_P0EDGE7 				(*((volatile PX_EDGE_REG *)(PORT_REG_BASE_ADDR + 0x06))).bit.PXEDGE7

// Px Port Interrupt Flag Register
// NOTE : The writing that used the bit field inhibits.
#define P0_IFLG 						(*((volatile PX_IFLG_REG *)(PORT_REG_BASE_ADDR + 0x07))).reg
#define P0_IFLG_P0IF					P0_IFLG 																	///< P0[7:0] port interrupt flag
#define P0_IFLG_P0IF0					(*((volatile PX_IFLG_REG *)(PORT_REG_BASE_ADDR + 0x07))).bit.PXIF0
#define P0_IFLG_P0IF1					(*((volatile PX_IFLG_REG *)(PORT_REG_BASE_ADDR + 0x07))).bit.PXIF1
#define P0_IFLG_P0IF2					(*((volatile PX_IFLG_REG *)(PORT_REG_BASE_ADDR + 0x07))).bit.PXIF2
#define P0_IFLG_P0IF3					(*((volatile PX_IFLG_REG *)(PORT_REG_BASE_ADDR + 0x07))).bit.PXIF3
#define P0_IFLG_P0IF4					(*((volatile PX_IFLG_REG *)(PORT_REG_BASE_ADDR + 0x07))).bit.PXIF4
#define P0_IFLG_P0IF5					(*((volatile PX_IFLG_REG *)(PORT_REG_BASE_ADDR + 0x07))).bit.PXIF5
#define P0_IFLG_P0IF6					(*((volatile PX_IFLG_REG *)(PORT_REG_BASE_ADDR + 0x07))).bit.PXIF6
#define P0_IFLG_P0IF7					(*((volatile PX_IFLG_REG *)(PORT_REG_BASE_ADDR + 0x07))).bit.PXIF7

// Px Port Chattering Filter Control Register
#define P0_CHAT 						(*((volatile PX_CHAT_REG *)(PORT_REG_BASE_ADDR + 0x08))).reg
#define P0_CHAT_P0CF2					(*((volatile PX_CHAT_REG *)(PORT_REG_BASE_ADDR + 0x08))).bit.PXCF2			///< P0[7:4] chattering filter time
#define P0_CHAT_P0CF1					(*((volatile PX_CHAT_REG *)(PORT_REG_BASE_ADDR + 0x08))).bit.PXCF1			///< P0[3:0] chattering filter time

#define P1_CHAT 						(*((volatile PX_CHAT_REG *)(PORT_REG_BASE_ADDR + 0x18))).reg
#define P1_CHAT_P1CF2					(*((volatile PX_CHAT_REG *)(PORT_REG_BASE_ADDR + 0x18))).bit.PXCF2			///< P1[7:4] chattering filter time
#define P1_CHAT_P1CF1					(*((volatile PX_CHAT_REG *)(PORT_REG_BASE_ADDR + 0x18))).bit.PXCF1			///< P1[3:0] chattering filter time

#define P2_CHAT 						(*((volatile PX_CHAT_REG *)(PORT_REG_BASE_ADDR + 0x28))).reg
#define P2_CHAT_P2CF1					P2_CHAT 																	///< P2[3:0] chattering filter time

// Px Port Key-Entry Reset Configuration Register
#define P0_KRST 						(*((volatile PX_KRST_REG *)(PORT_REG_BASE_ADDR + 0x09))).reg
#define P0_KRST_P0KRST					P0_KRST 																	///< P0[1:0] port key-entry reset configuration

// Px Port Inuput Enable Register
// NOTE : The bit field be the inhibition that uses it,
//		  because 1 is read at the time of read, in the case that there is reserve bit.
#define P0_IEN							(*((volatile PX_IEN_REG *)(PORT_REG_BASE_ADDR + 0x0a))).reg
#define P0_IEN_P0IEN					P0_IEN																		///< P0[7:0] port input enable
#define P0_IEN_P0IEN0					(*((volatile PX_IEN_REG *)(PORT_REG_BASE_ADDR + 0x0a))).bit.PXIEN0
#define P0_IEN_P0IEN1					(*((volatile PX_IEN_REG *)(PORT_REG_BASE_ADDR + 0x0a))).bit.PXIEN1
#define P0_IEN_P0IEN2					(*((volatile PX_IEN_REG *)(PORT_REG_BASE_ADDR + 0x0a))).bit.PXIEN2
#define P0_IEN_P0IEN3					(*((volatile PX_IEN_REG *)(PORT_REG_BASE_ADDR + 0x0a))).bit.PXIEN3
#define P0_IEN_P0IEN4					(*((volatile PX_IEN_REG *)(PORT_REG_BASE_ADDR + 0x0a))).bit.PXIEN4
#define P0_IEN_P0IEN5					(*((volatile PX_IEN_REG *)(PORT_REG_BASE_ADDR + 0x0a))).bit.PXIEN5
#define P0_IEN_P0IEN6					(*((volatile PX_IEN_REG *)(PORT_REG_BASE_ADDR + 0x0a))).bit.PXIEN6
#define P0_IEN_P0IEN7					(*((volatile PX_IEN_REG *)(PORT_REG_BASE_ADDR + 0x0a))).bit.PXIEN7

#define P1_IEN							(*((volatile PX_IEN_REG *)(PORT_REG_BASE_ADDR + 0x1a))).reg
#define P1_IEN_P1IEN					P1_IEN																		///< P10,P1[7:2] port input enable
#define P1_IEN_P1IEN0					(*((volatile PX_IEN_REG *)(PORT_REG_BASE_ADDR + 0x1a))).bit.PXIEN0
#define P1_IEN_P1IEN2					(*((volatile PX_IEN_REG *)(PORT_REG_BASE_ADDR + 0x1a))).bit.PXIEN2
#define P1_IEN_P1IEN3					(*((volatile PX_IEN_REG *)(PORT_REG_BASE_ADDR + 0x1a))).bit.PXIEN3
#define P1_IEN_P1IEN4					(*((volatile PX_IEN_REG *)(PORT_REG_BASE_ADDR + 0x1a))).bit.PXIEN4
#define P1_IEN_P1IEN5					(*((volatile PX_IEN_REG *)(PORT_REG_BASE_ADDR + 0x1a))).bit.PXIEN5
#define P1_IEN_P1IEN6					(*((volatile PX_IEN_REG *)(PORT_REG_BASE_ADDR + 0x1a))).bit.PXIEN6
#define P1_IEN_P1IEN7					(*((volatile PX_IEN_REG *)(PORT_REG_BASE_ADDR + 0x1a))).bit.PXIEN7

#define P2_IEN							(*((volatile PX_IEN_REG *)(PORT_REG_BASE_ADDR + 0x2a))).reg
#define P2_IEN_P2IEN					P2_IEN																		///< P1[7:0] port input enable
#define P2_IEN_P2IEN0					(*((volatile PX_IEN_REG *)(PORT_REG_BASE_ADDR + 0x2a))).bit.PXIEN0
#define P2_IEN_P2IEN1					(*((volatile PX_IEN_REG *)(PORT_REG_BASE_ADDR + 0x2a))).bit.PXIEN1
#define P2_IEN_P2IEN2					(*((volatile PX_IEN_REG *)(PORT_REG_BASE_ADDR + 0x2a))).bit.PXIEN2
#define P2_IEN_P2IEN3					(*((volatile PX_IEN_REG *)(PORT_REG_BASE_ADDR + 0x2a))).bit.PXIEN3


/***********************************************
 ****** The Definition of Real Time Clock  *****
 ****** [RTC]							   *****
 ***********************************************/
// RTC Control Register
#define RTC_CTL 						(*((volatile RTC_CTL_REG *)(RTC_REG_BASE_ADDR + 0x00))).reg
#define RTC_CTL_RTCST					(*((volatile RTC_CTL_REG *)(RTC_REG_BASE_ADDR + 0x00))).byte_reg[1] 		///< RTC run/stop status
#define RTC_CTL_BCDMD					(*((volatile RTC_CTL_REG *)(RTC_REG_BASE_ADDR + 0x00))).bit.BCDMD			///< BCD mode select
#define RTC_CTL_RTC24H					(*((volatile RTC_CTL_REG *)(RTC_REG_BASE_ADDR + 0x00))).bit.RTC24H			///< 24H/12H mode select
#define RTC_CTL_RTCRUN					(*((volatile RTC_CTL_REG *)(RTC_REG_BASE_ADDR + 0x00))).bit.RTCRUN			///< RTC run/stop control

// RTC Interrupt Enable Register
#define RTC_IEN 						(*((volatile RTC_IEN_REG *)(RTC_REG_BASE_ADDR + 0x02))).reg
#define RTC_IEN_INT1DEN 				(*((volatile RTC_IEN_REG *)(RTC_REG_BASE_ADDR + 0x02))).bit.INT1DEN 		///< 1-day interrupt enable
#define RTC_IEN_INTHDEN 				(*((volatile RTC_IEN_REG *)(RTC_REG_BASE_ADDR + 0x02))).bit.INTHDEN 		///< Half-day interrupt enable
#define RTC_IEN_INT1HEN 				(*((volatile RTC_IEN_REG *)(RTC_REG_BASE_ADDR + 0x02))).bit.INT1HEN 		///< 1-hour interrupt enable
#define RTC_IEN_INT10MEN				(*((volatile RTC_IEN_REG *)(RTC_REG_BASE_ADDR + 0x02))).bit.INT10MEN		///< 10-minute interrupt enable
#define RTC_IEN_INT1MEN 				(*((volatile RTC_IEN_REG *)(RTC_REG_BASE_ADDR + 0x02))).bit.INT1MEN 		///< 1-minute interrupt enable
#define RTC_IEN_INT10SEN				(*((volatile RTC_IEN_REG *)(RTC_REG_BASE_ADDR + 0x02))).bit.INT10SEN		///< 10-second interrupt enable
#define RTC_IEN_INT1HZEN				(*((volatile RTC_IEN_REG *)(RTC_REG_BASE_ADDR + 0x02))).bit.INT1HZEN		///< 1 Hz interrupt enable
#define RTC_IEN_INT4HZEN				(*((volatile RTC_IEN_REG *)(RTC_REG_BASE_ADDR + 0x02))).bit.INT4HZEN		///< 4 Hz interrupt enable
#define RTC_IEN_INT8HZEN				(*((volatile RTC_IEN_REG *)(RTC_REG_BASE_ADDR + 0x02))).bit.INT8HZEN		///< 8 Hz interrupt enable
#define RTC_IEN_INT32HZEN				(*((volatile RTC_IEN_REG *)(RTC_REG_BASE_ADDR + 0x02))).bit.INT32HZEN		///< 32 Hz interrupt enable

// RTC Interrupt Flag Register
#define RTC_IFLG						(*((volatile RTC_IFLG_REG *)(RTC_REG_BASE_ADDR + 0x04))).reg
#define RTC_IFLG_INT1D					(*((volatile RTC_IFLG_REG *)(RTC_REG_BASE_ADDR + 0x04))).bit.INT1D			///< 1-day interrupt flag
#define RTC_IFLG_INTHD					(*((volatile RTC_IFLG_REG *)(RTC_REG_BASE_ADDR + 0x04))).bit.INTHD			///< Half-day interrupt flag
#define RTC_IFLG_INT1H					(*((volatile RTC_IFLG_REG *)(RTC_REG_BASE_ADDR + 0x04))).bit.INT1H			///< 1-hour interrupt flag
#define RTC_IFLG_INT10M 				(*((volatile RTC_IFLG_REG *)(RTC_REG_BASE_ADDR + 0x04))).bit.INT10M 		///< 10-minute interrupt flag
#define RTC_IFLG_INT1M					(*((volatile RTC_IFLG_REG *)(RTC_REG_BASE_ADDR + 0x04))).bit.INT1M			///< 1-minute interrupt flag
#define RTC_IFLG_INT10S 				(*((volatile RTC_IFLG_REG *)(RTC_REG_BASE_ADDR + 0x04))).bit.INT10S 		///< 10-second interrupt flag
#define RTC_IFLG_INT1HZ 				(*((volatile RTC_IFLG_REG *)(RTC_REG_BASE_ADDR + 0x04))).bit.INT1HZ 		///< 1 Hz interrupt flag
#define RTC_IFLG_INT4HZ 				(*((volatile RTC_IFLG_REG *)(RTC_REG_BASE_ADDR + 0x04))).bit.INT4HZ 		///< 1 Hz interrupt flag
#define RTC_IFLG_INT8HZ 				(*((volatile RTC_IFLG_REG *)(RTC_REG_BASE_ADDR + 0x04))).bit.INT8HZ 		///< 8 Hz interrupt flag
#define RTC_IFLG_INT32HZ				(*((volatile RTC_IFLG_REG *)(RTC_REG_BASE_ADDR + 0x04))).bit.INT32HZ		///< 32 Hz interrupt flag

// RTC Minute/Second Counter Register
#define RTC_MS							(*((volatile RTC_MS_REG *)(RTC_REG_BASE_ADDR + 0x06))).reg
#define RTC_MS_RTCMIN					(*((volatile RTC_MS_REG *)(RTC_REG_BASE_ADDR + 0x06))).byte_reg[1]			///< Minute counter
#define RTC_MS_RTCSEC					(*((volatile RTC_MS_REG *)(RTC_REG_BASE_ADDR + 0x06))).byte_reg[0]			///< Second counter

// RTC Hour Counter Register
#define RTC_H							(*((volatile RTC_H_REG *)(RTC_REG_BASE_ADDR + 0x08))).reg
#define RTC_H_AMPM						(*((volatile RTC_H_REG *)(RTC_REG_BASE_ADDR + 0x08))).bit.AMPM				///< AM/PM
#define RTC_H_RTCHOUR					(*((volatile RTC_H_REG *)(RTC_REG_BASE_ADDR + 0x08))).bit.RTCHOUR			///< Hour counter


/***********************************************
 ****** The Definition of 8-bit Timer **********
 ****** [T8 Ch0]					  **********
 ***********************************************/
// 8-bit Timer Ch.x Input Clock Select Register
#define T8_CLK0 						(*((volatile T8_CLKN_REG *)(T8_REG_BASE_ADDR + 0x00))).reg
#define T8_CLK0_DF						T8_CLK0 																	///< Timer input clock select

// 8-bit Timer Ch.x Reload Data Register
#define T8_TR0							(*((volatile T8_TRN_REG *)(T8_REG_BASE_ADDR + 0x02))).reg
#define T8_TR0_TR						T8_TR0																		///< 8-bit timer reload data

// 8-bit Timer Ch.x Counter Data Register
#define T8_TC0							(*((volatile T8_TCN_REG *)(T8_REG_BASE_ADDR + 0x04))).reg
#define T8_TC0_TC						T8_TC0																		///< 8-bit timer counter data

// 8-bit Timer Ch.x Control Register
#define T8_CTL0 						(*((volatile T8_CTLN_REG *)(T8_REG_BASE_ADDR + 0x06))).reg
#define T8_CTL0_TRMD					(*((volatile T8_CTLN_REG *)(T8_REG_BASE_ADDR + 0x06))).bit.TRMD 			///< Count mode select
#define T8_CTL0_PRESER					(*((volatile T8_CTLN_REG *)(T8_REG_BASE_ADDR + 0x06))).bit.PRESER			///< Timer reset
#define T8_CTL0_PRUN					(*((volatile T8_CTLN_REG *)(T8_REG_BASE_ADDR + 0x06))).bit.PRUN 			///< Timer run/stop control

// 8-bit Timer Ch.x Interrupt Control Register
#define T8_INT0 						(*((volatile T8_INTN_REG *)(T8_REG_BASE_ADDR + 0x08))).reg
#define T8_INT0_T8IE					(*((volatile T8_INTN_REG *)(T8_REG_BASE_ADDR + 0x08))).byte_reg[1]			///< 8-bit Timer Interrupt enable
#define T8_INT0_T8IF					(*((volatile T8_INTN_REG *)(T8_REG_BASE_ADDR + 0x08))).byte_reg[0]			///< 8-bit Timer Interrupt flag


/***********************************************
 ****** The Definition of Advanced Timer	  **
 ****** [T16A2] 							   **
 ***********************************************/
// Advanced Timer Clock Control Register
#define T16A_CLK0						(*((volatile T16A_CLKN_REG *)(BASE_ADDR + 0x1068))).reg
#define T16A_CLK0_T16ACLKD				(*((volatile T16A_CLKN_REG *)(BASE_ADDR + 0x1068))).bit.T16ACLKD			///< T16A2 CH0 clock division ratio select
#define T16A_CLK0_T16ACLKSRC			(*((volatile T16A_CLKN_REG *)(BASE_ADDR + 0x1068))).bit.T16ACLKSRC			///< T16A2 CH0 clock source select
#define T16A_CLK0_T16ACLKE				(*((volatile T16A_CLKN_REG *)(BASE_ADDR + 0x1068))).bit.T16ACLKE			///< T16A2 CH0 clock enable

// Advanced Timer Control Register
#define T16A_CTL0						(*((volatile T16A_CTLN_REG *)(T16A2_REG_BASE_ADDR + 0x00))).reg
#define T16A_CTL0_HCM					(*((volatile T16A_CTLN_REG *)(T16A2_REG_BASE_ADDR + 0x00))).bit.HCM 		///< T16A2 CH0 Half clock mode enable select
#define T16A_CTL0_CBUFEN				(*((volatile T16A_CTLN_REG *)(T16A2_REG_BASE_ADDR + 0x00))).bit.CBUFEN		///< T16A2 CH0 Compare buffer enable
#define T16A_CTL0_TRMD					(*((volatile T16A_CTLN_REG *)(T16A2_REG_BASE_ADDR + 0x00))).bit.TRMD		///< T16A2 CH0 Counter mode
#define T16A_CTL0_PRESET				(*((volatile T16A_CTLN_REG *)(T16A2_REG_BASE_ADDR + 0x00))).bit.PRESET		///< T16A2 CH0 Counter reset
#define T16A_CTL0_PRUN					(*((volatile T16A_CTLN_REG *)(T16A2_REG_BASE_ADDR + 0x00))).bit.PRUN		///< T16A2 CH0 Counter Run/Stop

// Advanced Timer Counter Data Register
#define T16A_TC0						(*((volatile T16A_TCN_REG *)(T16A2_REG_BASE_ADDR + 0x02))).reg
#define T16A_TC0_T16ATC 				T16A_TC0																	///< T16A2 CH0 Counter data

// Advanced Timer Comparator/Capture Control Register
#define T16A_CCCTL0 					(*((volatile T16A_CCCTLN_REG *)(T16A2_REG_BASE_ADDR + 0x04))).reg
#define T16A_CCCTL0_CAPBTRG 			(*((volatile T16A_CCCTLN_REG *)(T16A2_REG_BASE_ADDR + 0x04))).bit.CAPBTRG	///< T16A2 CH0 Capture B trigger
#define T16A_CCCTL0_TOUTBMD 			(*((volatile T16A_CCCTLN_REG *)(T16A2_REG_BASE_ADDR + 0x04))).bit.TOUTBMD	///< T16A2 CH0 Timer OUT B mode
#define T16A_CCCTL0_TOUTBINV			(*((volatile T16A_CCCTLN_REG *)(T16A2_REG_BASE_ADDR + 0x04))).bit.TOUTBINV	///< T16A2 CH0 Timer OUT B register
#define T16A_CCCTL0_CCBMD				(*((volatile T16A_CCCTLN_REG *)(T16A2_REG_BASE_ADDR + 0x04))).bit.CCBMD 	///< T16A2 CH0 CCB register mode
#define T16A_CCCTL0_CAPATRG 			(*((volatile T16A_CCCTLN_REG *)(T16A2_REG_BASE_ADDR + 0x04))).bit.CAPATRG	///< T16A2 CH0 Capture A trigger
#define T16A_CCCTL0_TOUTAMD 			(*((volatile T16A_CCCTLN_REG *)(T16A2_REG_BASE_ADDR + 0x04))).bit.TOUTAMD	///< T16A2 CH0 Timer OUT A mode
#define T16A_CCCTL0_TOUTAINV			(*((volatile T16A_CCCTLN_REG *)(T16A2_REG_BASE_ADDR + 0x04))).bit.TOUTAINV	///< T16A2 CH0 Timer OUT A register
#define T16A_CCCTL0_CCAMD				(*((volatile T16A_CCCTLN_REG *)(T16A2_REG_BASE_ADDR + 0x04))).bit.CCAMD 	///< T16A2 CH0 CCA register mode

// Advanced Timer Comparator/Capture A Data Register
#define T16A_CCA0						(*((volatile T16A_CCXN_REG *)(T16A2_REG_BASE_ADDR + 0x06))).reg
#define T16A_CCA0_CCA					T16A_CCA0																	///< T16A2 CH0 Attached counter select

// Advanced Timer Comparator/Capture B Data Register
#define T16A_CCB0						(*((volatile T16A_CCXN_REG *)(T16A2_REG_BASE_ADDR + 0x08))).reg
#define T16A_CCB0_CCB					T16A_CCB0																	///< T16A2 CH0 Attached counter select

// Advanced Timer Comparator/Capture Interrupt Enable Register
#define T16A_IEN0						(*((volatile T16A_IENN_REG *)(T16A2_REG_BASE_ADDR + 0x0a))).reg
#define T16A_IEN0_CAPBOWIE				(*((volatile T16A_IENN_REG *)(T16A2_REG_BASE_ADDR + 0x0a))).bit.CAPBOWIE	///< T16A2 CH0 Capture B over write interrupt enable
#define T16A_IEN0_CAPAOWIE				(*((volatile T16A_IENN_REG *)(T16A2_REG_BASE_ADDR + 0x0a))).bit.CAPAOWIE	///< T16A2 CH0 Capture A over write interrupt enable
#define T16A_IEN0_CAPBIE				(*((volatile T16A_IENN_REG *)(T16A2_REG_BASE_ADDR + 0x0a))).bit.CAPBIE		///< T16A2 CH0 Capture B interrupt enable
#define T16A_IEN0_CAPAIE				(*((volatile T16A_IENN_REG *)(T16A2_REG_BASE_ADDR + 0x0a))).bit.CAPAIE		///< T16A2 CH0 Capture A interrupt enable
#define T16A_IEN0_CBIE					(*((volatile T16A_IENN_REG *)(T16A2_REG_BASE_ADDR + 0x0a))).bit.CBIE		///< T16A2 CH0 Compare B interrupt enable
#define T16A_IEN0_CAIE					(*((volatile T16A_IENN_REG *)(T16A2_REG_BASE_ADDR + 0x0a))).bit.CAIE		///< T16A2 CH0 Compare A interrupt enable

// Advanced Timer Comparator/Capture Interrupt Flag Register
#define T16A_IFLG0						(*((volatile T16A_IFLGN_REG *)(T16A2_REG_BASE_ADDR + 0x0c))).reg
#define T16A_IFLG0_CAPBOWIF 			(*((volatile T16A_IFLGN_REG *)(T16A2_REG_BASE_ADDR + 0x0c))).bit.CAPBOWIF	///< T16A2 CH0 Capture B over write interrupt enable
#define T16A_IFLG0_CAPAOWIF 			(*((volatile T16A_IFLGN_REG *)(T16A2_REG_BASE_ADDR + 0x0c))).bit.CAPAOWIF	///< T16A2 CH0 Capture A over write interrupt enable
#define T16A_IFLG0_CAPBIF				(*((volatile T16A_IFLGN_REG *)(T16A2_REG_BASE_ADDR + 0x0c))).bit.CAPBIF 	///< T16A2 CH0 Capture B interrupt enable
#define T16A_IFLG0_CAPAIF				(*((volatile T16A_IFLGN_REG *)(T16A2_REG_BASE_ADDR + 0x0c))).bit.CAPAIF 	///< T16A2 CH0 Capture A interrupt enable
#define T16A_IFLG0_CBIF 				(*((volatile T16A_IFLGN_REG *)(T16A2_REG_BASE_ADDR + 0x0c))).bit.CBIF		///< T16A2 CH0 Compare B interrupt enable
#define T16A_IFLG0_CAIF 				(*((volatile T16A_IFLGN_REG *)(T16A2_REG_BASE_ADDR + 0x0c))).bit.CAIF		///< T16A2 CH0 Compare A interrupt enable


/***********************************************
 ****** The Definition of Watchdog Timer *******
 ****** [WDT]							 *******
 ***********************************************/
// Watchdog Timer Control Register
#define WDT_CTL 						(*((volatile WDT_CTL_REG *)(WDT_REG_BASE_ADDR + 0x00))).reg
#define WDT_CTL_WDTRST					(*((volatile WDT_CTL_REG *)(WDT_REG_BASE_ADDR + 0x00))).bit.WDTRST			///< Watchdog timer reset
#define WDT_CTL_WDTRUN					(*((volatile WDT_CTL_REG *)(WDT_REG_BASE_ADDR + 0x00))).bit.WDTRUN			///< Watchdog timer run/stop control

// Watchdog Timer Status Register
#define WDT_ST							(*((volatile WDT_ST_REG *)(WDT_REG_BASE_ADDR + 0x01))).reg
#define WDT_ST_WDTMD					(*((volatile WDT_ST_REG *)(WDT_REG_BASE_ADDR + 0x01))).bit.WDTMD			///< NMI/Reset mode select
#define WDT_ST_WDTST					(*((volatile WDT_ST_REG *)(WDT_REG_BASE_ADDR + 0x01))).bit.WDTST			///< NMI status


/***********************************************
 ****** The Definition of UART		************
 ****** [UART (with IrDA)]			************
 ***********************************************/
// UART Ch.0 Status Register
#define UART_ST0						(*((volatile UART_STN_REG *)(UART_REG_BASE_ADDR + 0x00))).reg
#define UART_ST0_TRED					(*((volatile UART_STN_REG *)(UART_REG_BASE_ADDR + 0x00))).bit.TRED			///< End of transmission flag
#define UART_ST0_FER					(*((volatile UART_STN_REG *)(UART_REG_BASE_ADDR + 0x00))).bit.FER			///< Framing error flag
#define UART_ST0_PER					(*((volatile UART_STN_REG *)(UART_REG_BASE_ADDR + 0x00))).bit.PER			///< Parity error flag
#define UART_ST0_OER					(*((volatile UART_STN_REG *)(UART_REG_BASE_ADDR + 0x00))).bit.OER			///< Overrun error flag
#define UART_ST0_RD2B					(*((volatile UART_STN_REG *)(UART_REG_BASE_ADDR + 0x00))).bit.RD2B			///< Second byte receive flag
#define UART_ST0_TRBS					(*((volatile UART_STN_REG *)(UART_REG_BASE_ADDR + 0x00))).bit.TRBS			///< Transmit busy flag
#define UART_ST0_RDRY					(*((volatile UART_STN_REG *)(UART_REG_BASE_ADDR + 0x00))).bit.RDRY			///< Receive data ready flag
#define UART_ST0_TDBE					(*((volatile UART_STN_REG *)(UART_REG_BASE_ADDR + 0x00))).bit.TDBE			///< Transmit data buffer empty flag

// UART Ch.0 Transmit Data Register
#define UART_TXD0						(*((volatile UART_TXDN_REG *)(UART_REG_BASE_ADDR + 0x01))).reg
#define UART_TXD0_TXD					UART_TXD0																	///< Transmit data

// UART Ch.0 Receive Data Register
#define UART_RXD0						(*((volatile UART_RXDN_REG *)(UART_REG_BASE_ADDR + 0x02))).reg
#define UART_RXD0_RXD					UART_RXD0																	///< Receive data in the receive data buffer

// UART Ch.0 Mode Register
#define UART_MOD0						(*((volatile UART_MODN_REG *)(UART_REG_BASE_ADDR + 0x03))).reg
#define UART_MOD0_CHLN					(*((volatile UART_MODN_REG *)(UART_REG_BASE_ADDR + 0x03))).bit.CHLN 		///< Character length select
#define UART_MOD0_PREN					(*((volatile UART_MODN_REG *)(UART_REG_BASE_ADDR + 0x03))).bit.PREN 		///< Parity enable
#define UART_MOD0_PMD					(*((volatile UART_MODN_REG *)(UART_REG_BASE_ADDR + 0x03))).bit.PMD			///< Parity mode select
#define UART_MOD0_STPB					(*((volatile UART_MODN_REG *)(UART_REG_BASE_ADDR + 0x03))).bit.STPB 		///< Stop bit select

// UART Ch.0 Control Register
#define UART_CTL0						(*((volatile UART_CTLN_REG *)(UART_REG_BASE_ADDR + 0x04))).reg
#define UART_CTL0_TEIEN 				(*((volatile UART_CTLN_REG *)(UART_REG_BASE_ADDR + 0x04))).bit.TEIEN		///< End of transmission int. enable
#define UART_CTL0_REIEN 				(*((volatile UART_CTLN_REG *)(UART_REG_BASE_ADDR + 0x04))).bit.REIEN		///< Receive error int. enable
#define UART_CTL0_RIEN					(*((volatile UART_CTLN_REG *)(UART_REG_BASE_ADDR + 0x04))).bit.RIEN 		///< Receive buffer full int. enable
#define UART_CTL0_TIEN					(*((volatile UART_CTLN_REG *)(UART_REG_BASE_ADDR + 0x04))).bit.TIEN 		///< Transmit buffer empty int. enable
#define UART_CTL0_RBFI					(*((volatile UART_CTLN_REG *)(UART_REG_BASE_ADDR + 0x04))).bit.RBFI 		///< Receive buffer full int. condition
#define UART_CTL0_RXEN					(*((volatile UART_CTLN_REG *)(UART_REG_BASE_ADDR + 0x04))).bit.RXEN 		///< UART enable

// UART Ch.0 Expansion Register
#define UART_EXP0						(*((volatile UART_EXPN_REG *)(UART_REG_BASE_ADDR + 0x05))).reg
#define UART_EXP0_IRMD					UART_EXP0																	///< IrDA mode select

// UART Ch.0 Baud Rate Register
#define UART_BR0						(*((volatile UART_BRN_REG *)(UART_REG_BASE_ADDR + 0x06))).reg
#define UART_BR0_BR 					UART_BR0																	///< Baud rate setting

// UART Ch.0 Fine Mode Register
#define UART_FMD0						(*((volatile UART_FMDN_REG *)(UART_REG_BASE_ADDR + 0x07))).reg
#define UART_FMD0_FMD					UART_FMD0																	///< Fine mode setup

// UART Ch.0 Clock Control Register
#define UART_CLK0						(*((volatile UART_CLKN_REG *)(BASE_ADDR + 0x106c))).reg
#define UART_CLK0_UTCLKD				(*((volatile UART_CLKN_REG *)(BASE_ADDR + 0x106c))).bit.UTCLKD				///< Clock division ratio select
#define UART_CLK0_UTCLKSRC				(*((volatile UART_CLKN_REG *)(BASE_ADDR + 0x106c))).bit.UTCLKSRC			///< Clock source select
#define UART_CLK0_UTCLKE				(*((volatile UART_CLKN_REG *)(BASE_ADDR + 0x106c))).bit.UTCLKE				///< UART clock enable


/***********************************************
 ****** The Definition of SPI		  **********
 ****** [SPI]						  **********
 ***********************************************/
// SPI Ch.0 Status Register
#define SPI_ST0 						(*((volatile SPI_STN_REG *)(SPI_REG_BASE_ADDR + 0x00))).reg
#define SPI_ST0_SPBSY					(*((volatile SPI_STN_REG *)(SPI_REG_BASE_ADDR + 0x00))).bit.SPBSY			///< Transfer busy flag(master) / ss signal low flag(slave) (read only)
#define SPI_ST0_SPRBF					(*((volatile SPI_STN_REG *)(SPI_REG_BASE_ADDR + 0x00))).bit.SPRBF			///< Receive data buffer full flag (read only)
#define SPI_ST0_SPTBE					(*((volatile SPI_STN_REG *)(SPI_REG_BASE_ADDR + 0x00))).bit.SPTBE			///< Transmit data buffer empty flag (read only)

// SPI Ch.0 Transmit Data Register
#define SPI_TXD0						(*((volatile SPI_TXDN_REG *)(SPI_REG_BASE_ADDR + 0x02))).reg
#define SPI_TXD0_SPTDB					SPI_TXD0																	///< SPI transmit data buffer

// SPI Ch.0 Receive Data Register
#define SPI_RXD0						(*((volatile SPI_RXDN_REG *)(SPI_REG_BASE_ADDR + 0x04))).reg
#define SPI_RXD0_SPRDB					SPI_RXD0																	///< SPI receive data buffer

// SPI Ch.0 Control Register
#define SPI_CTL0						(*((volatile SPI_CTLN_REG *)(SPI_REG_BASE_ADDR + 0x06))).reg
#define SPI_CTL0_MCLK					(*((volatile SPI_CTLN_REG *)(SPI_REG_BASE_ADDR + 0x06))).bit.MCLK			///< SPI clock source select
#define SPI_CTL0_MLSB					(*((volatile SPI_CTLN_REG *)(SPI_REG_BASE_ADDR + 0x06))).bit.MLSB			///< LSB/MSB first mode select
#define SPI_CTL0_SPRIE					(*((volatile SPI_CTLN_REG *)(SPI_REG_BASE_ADDR + 0x06))).bit.SPRIE			///< Receive data buffer full int. enable
#define SPI_CTL0_SPTIE					(*((volatile SPI_CTLN_REG *)(SPI_REG_BASE_ADDR + 0x06))).bit.SPTIE			///< Transmit data buffer empty int. enable
#define SPI_CTL0_CPHA					(*((volatile SPI_CTLN_REG *)(SPI_REG_BASE_ADDR + 0x06))).bit.CPHA			///< Clock phase select
#define SPI_CTL0_CPOL					(*((volatile SPI_CTLN_REG *)(SPI_REG_BASE_ADDR + 0x06))).bit.CPOL			///< Clock polarity select
#define SPI_CTL0_MSSL					(*((volatile SPI_CTLN_REG *)(SPI_REG_BASE_ADDR + 0x06))).bit.MSSL			///< Master/slave mode select
#define SPI_CTL0_SPEN					(*((volatile SPI_CTLN_REG *)(SPI_REG_BASE_ADDR + 0x06))).bit.SPEN			///< SPI enable


/***********************************************
 ****** The Definition of LCD Driver ***********
 ****** [LCD]						 ***********
 ***********************************************/
// LCD Timing Clock Select Register
#define LCD_TCLK						(*((volatile LCD_TCLK_REG *)(LCD_REG_BASE_ADDR + 0x00))).reg
#define LCD_TCLK_LCDTCLKD				(*((volatile LCD_TCLK_REG *)(LCD_REG_BASE_ADDR + 0x00))).bit.LCDTCLKD		///< LCD clock division ratio select
#define LCD_TCLK_LCDTCLKSRC 			(*((volatile LCD_TCLK_REG *)(LCD_REG_BASE_ADDR + 0x00))).bit.LCDTCLKSRC 	///< LCD clock source select
#define LCD_TCLK_LCDTCLKE				(*((volatile LCD_TCLK_REG *)(LCD_REG_BASE_ADDR + 0x00))).bit.LCDTCLKE		///< LCD clock enable

// LCD Booster Clock Control Register
#define LCD_BCLK						(*((volatile LCD_BCLK_REG *)(LCD_REG_BASE_ADDR + 0x01))).reg
#define LCD_BCLK_LCDBCLKD				(*((volatile LCD_BCLK_REG *)(LCD_REG_BASE_ADDR + 0x01))).bit.LCDBCLKD		///< LCD booster clock division ratio select
#define LCD_BCLK_LCDBCLKSRC 			(*((volatile LCD_BCLK_REG *)(LCD_REG_BASE_ADDR + 0x01))).bit.LCDBCLKSRC 	///< LCD booster clock source select
#define LCD_BCLK_LCDBCLKE				(*((volatile LCD_BCLK_REG *)(LCD_REG_BASE_ADDR + 0x01))).bit.LCDBCLKE		///< LCD booster clock enable

// LCD Display Control Register
#define LCD_DCTL						(*((volatile LCD_DCTL_REG *)(LCD_REG_BASE_ADDR + 0x30))).reg
#define LCD_DCTL_DSPREV 				(*((volatile LCD_DCTL_REG *)(LCD_REG_BASE_ADDR + 0x30))).bit.DSPREV 		///< Reverse display control
#define LCD_DCTL_DSPC					(*((volatile LCD_DCTL_REG *)(LCD_REG_BASE_ADDR + 0x30))).bit.DSPC			///< LDC display control

// LCD Clock Control Register
#define LCD_CCTL						(*((volatile LCD_CCTL_REG *)(LCD_REG_BASE_ADDR + 0x32))).reg
#define LCD_CCTL_FRMCNT 				(*((volatile LCD_CCTL_REG *)(LCD_REG_BASE_ADDR + 0x32))).bit.FRMCNT 		///< Frame freq control
#define LCD_CCTL_LDUTY					(*((volatile LCD_CCTL_REG *)(LCD_REG_BASE_ADDR + 0x32))).bit.LDUTY			///< LCD duty select

// LCD Voltage Regulator Control Register
#define LCD_VREG						(*((volatile LCD_VREG_REG *)(LCD_REG_BASE_ADDR + 0x33))).reg
#define LCD_VREG_LHVLD					(*((volatile LCD_VREG_REG *)(LCD_REG_BASE_ADDR + 0x33))).bit.LHVLD			///< Vc heavy load protection mode
#define LCD_VREG_VCSEL					(*((volatile LCD_VREG_REG *)(LCD_REG_BASE_ADDR + 0x33))).bit.VCSEL			///< Reference voltage select

// LCD Interrupt Mask Register
#define LCD_IMSK						(*((volatile LCD_IMSK_REG *)(LCD_REG_BASE_ADDR + 0x35))).reg
#define LCD_IMSK_IFRMEN 				LCD_IMSK																	///< Frame signal interrupt enable

// LCD Interrupt Flag Register
#define LCD_IFLG						(*((volatile LCD_IFLG_REG *)(LCD_REG_BASE_ADDR + 0x36))).reg
#define LCD_IFLG_IFRMFLG				LCD_IFLG																	///< Frame signal interrupt flag


/***********************************************
 ****** The Definition of Sound Generator ******
 ****** [SND]							  ******
 ***********************************************/
// SND Clock Control Register
#define SND_CLK 						(*((volatile SND_CLK_REG *)(CLG_REG_BASE_ADDR + 0x0e))).reg
#define SND_CLK_SNDCLKE 				SND_CLK 																	///< SND clock enable

// SND Control Register
#define SND_CTL 						(*((volatile SND_CTL_REG *)(SND_REG_BASE_ADDR + 0x00))).reg
#define SND_CTL_BZTM					(*((volatile SND_CTL_REG *)(SND_REG_BASE_ADDR + 0x00))).bit.BZTM			///< Buzzer envelope time/one-shot output time select
#define SND_CTL_BZMD					(*((volatile SND_CTL_REG *)(SND_REG_BASE_ADDR + 0x00))).bit.BZMD			///< Buzzer mode select
#define SND_CTL_BZEN					(*((volatile SND_CTL_REG *)(SND_REG_BASE_ADDR + 0x00))).bit.BZEN			///< Buzzer output control

// Buzzer Frequency Control Register
#define SND_BZFQ						(*((volatile SND_BZFQ_REG *)(SND_REG_BASE_ADDR + 0x01))).reg
#define SND_BZFQ_BZFQ					SND_BZFQ																	///< Buzzer frequency select

// Buzzer Duty Ratio
#define SND_BZDT						(*((volatile SND_BZDT_REG *)(SND_REG_BASE_ADDR + 0x02))).reg
#define SND_BZDT_BZDT					SND_BZDT																	///< Buzzer duty ratio select


/***********************************************
 ****** The Definition of SVD Circuit **********
 ****** [SVD]						  **********
 ***********************************************/
// SVD Clock control Register
#define SVD_CLK 						(*((volatile SVD_CLK_REG *)(CLG_REG_BASE_ADDR + 0x06))).reg
#define SVD_CLK_CLKSRC					(*((volatile SVD_CLK_REG *)(CLG_REG_BASE_ADDR + 0x06))).bit.CLKSRC			///< SVD clock source select
#define SVD_CLK_CLKEN					(*((volatile SVD_CLK_REG *)(CLG_REG_BASE_ADDR + 0x06))).bit.CLKEN			///< SVD clock enable

// SVD Enable Register
#define SVD_EN							(*((volatile SVD_EN_REG *)(SVD_REG_BASE_ADDR + 0x00))).reg
#define SVD_EN_SVDRE					(*((volatile SVD_EN_REG *)(SVD_REG_BASE_ADDR + 0x00))).bit.SVDRE			///< SVD reset enable
#define SVD_EN_SVDMD					(*((volatile SVD_EN_REG *)(SVD_REG_BASE_ADDR + 0x00))).bit.SVDMD			///< SVD mode
#define SVD_EN_SVDEN					(*((volatile SVD_EN_REG *)(SVD_REG_BASE_ADDR + 0x00))).bit.SVDEN			///< SVD enable

// SVD Compare Voltage Register
#define SVD_CMP 						(*((volatile SVD_CMP_REG *)(SVD_REG_BASE_ADDR + 0x01))).reg
#define SVD_CMP_VDSEL					(*((volatile SVD_CMP_REG *)(SVD_REG_BASE_ADDR + 0x01))).bit.VDSEL			///< SVD Detecttion voltage select
#define SVD_CMP_SVDSC					(*((volatile SVD_CMP_REG *)(SVD_REG_BASE_ADDR + 0x01))).bit.SVDSC			///< SVD sampling result
#define SVD_CMP_SVDC					(*((volatile SVD_CMP_REG *)(SVD_REG_BASE_ADDR + 0x01))).bit.SVDC			///< SVD compare voltage

// SVD Detection Result Register
#define SVD_RSLT						(*((volatile SVD_RSLT_REG *)(SVD_REG_BASE_ADDR + 0x02))).reg
#define SVD_RSLT_SVDDT					SVD_RSLT																	///< SVD detection result

// SVD Interrupt mask Register
#define SVD_IMSK						(*((volatile SVD_IMSK_REG *)(SVD_REG_BASE_ADDR + 0x03))).reg
#define SVD_IMSK_SVDIE					SVD_IMSK																	///< SVD Interrupt mask

// SVD Interrupt flag Register
#define SVD_IFLG						(*((volatile SVD_IFLG_REG *)(SVD_REG_BASE_ADDR + 0x04))).reg
#define SVD_IFLG_SVDIF					SVD_IFLG																	///< SVD Interrupt flag


/***********************************************
 ****** The Definition of Power Generator ******
 ****** [VD1]							  ******
 ***********************************************/
// VD1 Control Register
#define VD1_CTL 						(*((volatile VD1_CTL_REG *)(VD1_REG_BASE_ADDR + 0x00))).reg
#define VD1_CTL_HVLD					(*((volatile VD1_CTL_REG *)(VD1_REG_BASE_ADDR + 0x00))).bit.HVLD			///< VD1 heavy load protection mode


/***********************************************
 ****** The Definition of R/F Converter   ******
 ****** [RFC]							  ******
 ***********************************************/
// RFC Ch.0 Clock Control Register
#define RFC_CLK 						(*((volatile RFC_CLK_REG *)(CLG_REG_BASE_ADDR + 0x07))).reg
#define RFC_CLK_CLKDIV					(*((volatile RFC_CLK_REG *)(CLG_REG_BASE_ADDR + 0x07))).bit.CLKDIV			///< These bits select the division ratio of the RFC operating clock.
#define RFC_CLK_CLKSRC					(*((volatile RFC_CLK_REG *)(CLG_REG_BASE_ADDR + 0x07))).bit.CLKSRC			///< These bits select the clock source of the RFC.
#define RFC_CLK_CLKEN					(*((volatile RFC_CLK_REG *)(CLG_REG_BASE_ADDR + 0x07))).bit.CLKEN			///< This bit sets whether the RFC operating clock enable.

// RFC Ch.0 Control Register
#define RFC_CTL 						(*((volatile RFC_CTL_REG *)(RFC_REG_BASE_ADDR + 0x00))).reg
#define RFC_CTL_CONEN					(*((volatile RFC_CTL_REG *)(RFC_REG_BASE_ADDR + 0x00))).bit.CONEN			///< This bit enables external clock input mode (event counter mode).
#define RFC_CTL_EVTEN					(*((volatile RFC_CTL_REG *)(RFC_REG_BASE_ADDR + 0x00))).bit.EVTEN			///< These bits configure the oscillation mode.
#define RFC_CTL_RFCEN					(*((volatile RFC_CTL_REG *)(RFC_REG_BASE_ADDR + 0x00))).bit.RFCEN			///< This bit enables the RFC operations.

// RFC Ch.0 Oscillation Trigger Register
#define RFC_TRG 						(*((volatile RFC_TRG_REG *)(RFC_REG_BASE_ADDR + 0x02))).reg
#define RFC_TRG_SSENB					(*((volatile RFC_TRG_REG *)(RFC_REG_BASE_ADDR + 0x02))).bit.SSENB			///< This bit controls CR oscillation for sensor B.
#define RFC_TRG_SSENA					(*((volatile RFC_TRG_REG *)(RFC_REG_BASE_ADDR + 0x02))).bit.SSENA			///< This bit controls CR oscillation for sensor A.
#define RFC_TRG_SREF					(*((volatile RFC_TRG_REG *)(RFC_REG_BASE_ADDR + 0x02))).bit.SREF			///< This bit controls CR oscillation for the reference resistor.

// RFC Ch.0 Measurement Counter Low Register
// RFC Ch.0 Measurement Counter High Register
#define RFC_MC							(*((volatile RFC_MC_REG *)(RFC_REG_BASE_ADDR + 0x04))).reg
#define RFC_MC_0_23 					RFC_MC																		///< Measurement counter data can be read and written through these bits.

// RFC Ch.0 Time Base Counter Low Register
// RFC Ch.0 Time Base Counter High Register
#define RFC_TC							(*((volatile RFC_TC_REG *)(RFC_REG_BASE_ADDR + 0x08))).reg
#define RFC_TC_0_23 					RFC_TC																		///< Time base counter data can be read and written through these bits.

// RFC Ch.0 Interrupt Mask Register
#define RFC_IMSK						(*((volatile RFC_IMSK_REG *)(RFC_REG_BASE_ADDR + 0x0C))).reg
#define RFC_IMSK_OVTCIE 				(*((volatile RFC_IMSK_REG *)(RFC_REG_BASE_ADDR + 0x0C))).bit.OVTCIE 		///< This bit indicate Time base counter overflow error interrupt cause occurrence status.
#define RFC_IMSK_OVMCIE 				(*((volatile RFC_IMSK_REG *)(RFC_REG_BASE_ADDR + 0x0C))).bit.OVMCIE 		///< This bit indicate Measurement counter overflow error interrupt cause occurrence status.
#define RFC_IMSK_ESENBIE				(*((volatile RFC_IMSK_REG *)(RFC_REG_BASE_ADDR + 0x0C))).bit.ESENBIE		///< This bit indicate Sensor B oscillation completion interrupt cause occurrence status.
#define RFC_IMSK_ESENAIE				(*((volatile RFC_IMSK_REG *)(RFC_REG_BASE_ADDR + 0x0C))).bit.ESENAIE		///< This bit indicate Sensor A oscillation completion interrupt cause occurrence status.
#define RFC_IMSK_EREFIE 				(*((volatile RFC_IMSK_REG *)(RFC_REG_BASE_ADDR + 0x0C))).bit.EREFIE 		///< This bit indicate Reference oscillation completion interrupt cause occurrence status.

// RFC Ch.0 Interrupt Flag Register
#define RFC_IFLG						(*((volatile RFC_IFLG_REG *)(RFC_REG_BASE_ADDR + 0x0E))).reg
#define RFC_IFLG_OVTCIF 				(*((volatile RFC_IFLG_REG *)(RFC_REG_BASE_ADDR + 0x0E))).bit.OVTCIF 		///< This bit enable Time base counter overflow error interrupt.
#define RFC_IFLG_OVMCIF 				(*((volatile RFC_IFLG_REG *)(RFC_REG_BASE_ADDR + 0x0E))).bit.OVMCIF 		///< This bit enable Measurement counter overflow error interrupt.
#define RFC_IFLG_ESENBIF				(*((volatile RFC_IFLG_REG *)(RFC_REG_BASE_ADDR + 0x0E))).bit.ESENBIF		///< This bit enable Sensor B oscillation completion interrupt.
#define RFC_IFLG_ESENAIF				(*((volatile RFC_IFLG_REG *)(RFC_REG_BASE_ADDR + 0x0E))).bit.ESENAIF		///< This bit enable Sensor A oscillation completion interrupt.
#define RFC_IFLG_EREFIF 				(*((volatile RFC_IFLG_REG *)(RFC_REG_BASE_ADDR + 0x0E))).bit.EREFIF 		///< This bit enable Reference oscillation completion interrupt.


#ifdef __cplusplus
}
#endif

#endif	// C17656_REG_H__

