/****************************************************************************
 *
 * @file	port.h
 * @brief	This is port driver header file for S1C17656.
 *
 * @par		Copyright:
 *			Copyright(C) SEIKO EPSON CORPORATION 2014-2014. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 2014/08/20	1.00
 *				- First revision
 *
 ***************************************************************************/

#ifndef _PORT_H
#define _PORT_H

/*
 * Declarations of function prototype
 */
extern void SetPortInput( unsigned char inputPort0, unsigned char inputPort1, unsigned char inputPort2 );
extern void SetPortOutput(	unsigned char outputPort0, unsigned char outputPort1, unsigned char outputPort2 );
extern int  SetPortOutputData(	unsigned char portCh, unsigned char outputData );
extern void SetP0Chat(unsigned char p0p3Chat, unsigned char p4p7Chat);
extern int  InitP0Int( unsigned char intLevel, unsigned char p0Edge );
extern void EnableP0Int( unsigned char p0Imsk);
extern void DisableP0Int( unsigned char p0Imsk );
extern int  isP0Int(unsigned char Intbit);
extern void ClrP0IntFlg( unsigned char Intbit );

/// End Status
#define PORT_SET_NG				( 0 )		///< Fail
#define PORT_SET_OK				( 1 )		///< Success
#define PORT_NOTOCCURRED			( 0 )		///< not occurred
#define PORT_OCCURRED				( 1 )		///< occurred

/// Port Number
#define PORT_PORTNO_0				( 0 )		///< Port 0
#define PORT_PORTNO_1				( 1 )		///< Port 1
#define PORT_PORTNO_2				( 2 )		///< Port 2

/// Chattering Time Select
#define P_CAHT_TIME_NONE			( 0 )		///< NONE
#define P_CAHT_TIME_PCLK_256		( 1 )		///< 256/PCLK
#define P_CAHT_TIME_PCLK_512		( 2 )		///< 512/PCLK
#define P_CAHT_TIME_PCLK_1024		( 3 )		///< 1024/PCLK
#define P_CAHT_TIME_PCLK_2048		( 4 )		///< 2048/PCLK
#define P_CAHT_TIME_PCLK_4096		( 5 )		///< 4096/PCLK
#define P_CAHT_TIME_PCLK_8192		( 6 )		///< 8192/PCLK
#define P_CAHT_TIME_PCLK_16384		( 7 )		///< 16384/PCLK

/// Interrupt Level
#define PORT_INTLV_0				( 0 )		///< Interrupt Level 0
#define PORT_INTLV_1				( 1 )		///< Interrupt Level 1
#define PORT_INTLV_2				( 2 )		///< Interrupt Level 2
#define PORT_INTLV_3				( 3 )		///< Interrupt Level 3
#define PORT_INTLV_4				( 4 )		///< Interrupt Level 4
#define PORT_INTLV_5				( 5 )		///< Interrupt Level 5
#define PORT_INTLV_6				( 6 )		///< Interrupt Level 6
#define PORT_INTLV_7				( 7 )		///< Interrupt Level 7

/// PORT Bit
#define P_BIT_X0					( 0x01 )	///< PX0
#define P_BIT_X1					( 0x02 )	///< PX1
#define P_BIT_X2					( 0x04 )	///< PX2
#define P_BIT_X3					( 0x08 )	///< PX3
#define P_BIT_X4					( 0x10 )	///< PX4
#define P_BIT_X5					( 0x20 )	///< PX5
#define P_BIT_X6					( 0x40 )	///< PX6
#define P_BIT_X7					( 0x80 )	///< PX7

/// Output Data
#define PORT_MAIN_PORT_OUT_LOW	 	( 0 )		///< Low Level
#define PORT_MAIN_PORT_OUT_HIGH 	( 1 )		///< High Level


#endif	// _PORT_H

