/********************************************************************************
 *
 * @file	main.c
 * @brief	This is snd-sample program for S1C17656 demonstration.
 *
 * @par		Copyright:
 *			Copyright(C) SEIKO EPSON CORPORATION 2014-2014. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 2014/08/20	1.00
 *				- First revision
 *
 *******************************************************************************/
/********************************************************************************
 * @mainpage	S1C17656 SND
 *
 * @section		intro Introduction
 * Sample code uses Envelope mode of SND.
 * The code outputs waveform to BZOUT terminal.
 *
 * @subsection	step1	Step 1: Start OSC1A.
 *						Start OSC1A.
 * @subsection	step2	Step 2: Initialize SND.
 *						Initialize SND.
 * @subsection	step3	Step 3: Run SND.
 *						Run SND until buzzer frequency is '1170.3Hz'.
 * @subsection	step4	Step 4: Stop SND.
 *						Stop SND.
 *						End SND sample code.
 *
 * @section		install Installation
 * Start the IDE and import the "s1c17656_snd" project.
 *
 *******************************************************************************/

/// #include
#include <string.h>
#include <stdio.h>
#include <c17656_reg.h>
#include <init.h>
#include <snd.h>
#include <clg.h>
#include <t8.h>

/// Prototype
int main(void);
void IntT8(void)__attribute__ ((interrupt_handler));

#define COUNTMAX					( 8 )			///< freqCount count over status

volatile unsigned int t8Count;
volatile unsigned int t8flag;
volatile long i;

/****************************************************************************
 * Main function.
 *
 * @retval	1	Normality
 * @retval	0	Abnormality
 ***************************************************************************/
int main(void)
{
	int freqCount = 0;
	double freqDispStatus[] = {
		4096.0, 3276.8, 2730.7, 2340.6, 2048.0, 1638.4, 1365.3, 1170.3
	};
	unsigned char freqData[] = {
		0, 1, 2, 3,
		4, 5, 6, 7
	};
	int rnf;
	int rnf_main = 1;
	SND_BZ_MODE mode;

	DebugModeMisc( 0 );			/// Misc Stop in Debug Mode
	DebugModePsc( 0 );			/// Prescaler Stop in Debug Mode
	SetClockGear( 0 );			/// Set Clock Gear *default=0x0
	ControlClg( 3 );			/// Run Clg

	printf("<<< Sound Generator demonstration start >>>\n");

/** OSC1A **/
	/// OSC1A Wait Cycle
	rnf = SetWaitCycleClg( 0, 0 );
	if ( rnf == 0 ) {
		printf("***  SetWaitCycleClg ERROR  ***\n");
		rnf_main = 0;
	}
	/// OSC1A run enable
	rnf = StartOSC1();
	if( rnf == 0 ){
		printf("***  StartOSC1 ERROR  ***\n");
		rnf_main = 0;
	}

	int	m,n;
	for( m = 0 ; m < 61; m++ ){			/// Wait 16384 * 2000000/32768 Cycle
		for( n = 0 ; n < 16384; n++ ){
			asm ( "nop" );
		}
	}

/** T8 **/
	/// T8 Initialize
	rnf = InitT8( 0, 3, 0xFA );
	if( rnf == 0 ){
		printf("***  InitT8 ERROR  ***\n");
		rnf_main = 0;
	}
	/// Interrupt Initialize
	rnf = InitT8Int( 3 );
	if( rnf == 0 ){
		printf("***  InitT8Int ERROR  ***\n");
		rnf_main = 0;
	}

/** SND **/
	/// Set SND clock enable
	SND_CLK |= 0x01;
	/// Set PORT function
	P04_07PMUX = 0x50;


	/// Run SND
	while( 7 >= freqCount ){

		/// Display to simulated I/O window
		printf("*** Buzzer Frequency : %.1f Hz ***\n", freqDispStatus[freqCount]);

		/// Initialize NORMAL mode
		mode.bzfq = freqData[freqCount];
		mode.bzmd = 0;
		mode.bztm = 3;
		mode.duty = 3;
		rnf = InitSND( &mode );
		if( rnf == 0 ){
			printf("***  InitSND ERROR  ***\n");
			rnf_main = 0;
		}

		t8Count = 0;
		t8flag = 0;
		/// Interrupt enable
		EnableT8Int();
		/// Timer Start
		StartT8();
		/// Start SND
		StartSND();
		while ( t8flag == 0 ) {
			asm ( "ei" );
			asm ( "halt" );
			asm ( "nop" );
			asm ( "di" );
		}
		/// Stop SND
		StopSND();
		/// Stop T8
		StopT8();
		/// Interrupt disable
		DisableT8Int();


		/// Initialize ENVELOPE mode
		mode.bzfq = freqData[freqCount];
		mode.bzmd = 2;
		mode.bztm = 3;
		mode.duty = 0;
		rnf = InitSND( &mode );
		if( rnf == 0 ){
			printf("***  InitSND ERROR  ***\n");
			rnf_main = 0;
		}


		/// Start SND
		StartSND();
		for ( i=0; i<0x40000; i++ ){
			if (  SND_CTL_BZEN != 0 ) {
				break;
			}
		}
		/// Wait until sound end
		while( SND_CTL_BZEN != 0 ){
			;
		}

		freqCount++;

	}

	/// Stop SND
	StopSND();

	/// Set SND clock disable
	SND_CLK &= 0xfe;

	printf("<<< Sound Generator demonstration finish >>>\n");

	return ( rnf_main );

}

/****************************************************************************
 * IntT8 function.
 *
 * @brief	 T8 interrupt routine.
 ***************************************************************************/
void IntT8(void)
{
	/** 1 msec timer **/

	/// Clear interrupt flag
	ClrT8IntFlg();

	t8Count++;
	if( t8Count >= 1000 ){
		t8flag = 1;
	}
}


