/****************************************************************************
 *
 * @file	snd.h
 * @brief	This is snd driver header file for S1C17656.
 *
 * @par		Copyright:
 *			Copyright(C) SEIKO EPSON CORPORATION 2014-2014. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 2014/08/20	1.00
 *				- First revision
 *
 ***************************************************************************/
#ifndef _SND_H
#define _SND_H

typedef struct
{
	unsigned char		bzmd;
	unsigned char		bztm;
	unsigned char		bzfq;
	unsigned char		duty;
}SND_BZ_MODE;


extern int InitSND( SND_BZ_MODE *mode );
extern void StartSND(void);
extern void StopSND(void);


/// SND End Status
#define SND_NG						( 0 )		///< Fail
#define SND_OK						( 1 )		///< Success

/// SND Clock Enable/Disable
#define SNDCLKSNDCLKE_DISABLE		( 0 )		///< Disable
#define SNDCLKSNDCLKE_ENABLE		( 1 )		///< Enable

/// SND Buzzer Output Control
#define SNDCTLBZEN_OFF				( 0 )		///< OFF
#define SNDCTLBZEN_ON				( 1 )		///< ON/Trigger

/// SND Buzzer Mode Select
#define SND_NORMALMD				( 0 )		///< Normal mode
#define SND_ONTSHOTMD				( 1 )		///< One-shot mode
#define SND_ENVELOPEMD				( 2 )		///< Envelope mode

/// SND Buzzer Envelope Time / One-shot Output Time Select
#define SND_15630_TIME				( 0 )		///< 15.63 seconds
#define SND_31250_TIME				( 1 )		///< 31.25 seconds
#define SND_62500_TIME				( 2 )		///< 62.50 seconds
#define SND_125000_TIME			( 3 )		///< 125.0 seconds

/// SND Buzzer Frequency Select
#define SND_4096000_FRQ			( 0 )		///< 4096.0 Hz
#define SND_3276800_FRQ			( 1 )		///< 3276.8 Hz
#define SND_2730700_FRQ			( 2 )		///< 2730.7 Hz
#define SND_2340600_FRQ			( 3 )		///< 2340.6 Hz
#define SND_2048000_FRQ			( 4 )		///< 2048.0 Hz
#define SND_1638400_FRQ			( 5 )		///< 1638.4 Hz
#define SND_1365300_FRQ			( 6 )		///< 1365.3 Hz
#define SND_1170300_FRQ			( 7 )		///< 1170.3 Hz

/// SND Buzzer Duty Ratio Select
#define SND_BZDUTY_1				( 0 )		///< Buzzer duty ratio 1
#define SND_BZDUTY_2				( 1 )		///< Buzzer duty ratio 2
#define SND_BZDUTY_3				( 2 )		///< Buzzer duty ratio 3
#define SND_BZDUTY_4				( 3 )		///< Buzzer duty ratio 4
#define SND_BZDUTY_5				( 4 )		///< Buzzer duty ratio 5
#define SND_BZDUTY_6				( 5 )		///< Buzzer duty ratio 6
#define SND_BZDUTY_7				( 6 )		///< Buzzer duty ratio 7
#define SND_BZDUTY_8				( 7 )		///< Buzzer duty ratio 8


#endif	// _SND_H_
