/****************************************************************************
 *
 * @file	spi.h
 * @brief	This is spi driver header file for S1C17656.
 *
 * @par		Copyright:
 *			Copyright(C) SEIKO EPSON CORPORATION 2014-2014. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 2014/08/20	1.00
 *				- First revision
 *
 ***************************************************************************/
#ifndef SPI_H_
#define SPI_H_

typedef struct
{
	unsigned short		selectClk;
	unsigned short		selectMLSB;
	unsigned short		selectPhase;
	unsigned short		selectPolarity;
	unsigned short		selectMode;
}SPI_INIT_PARAM;

extern int  InitSPI( SPI_INIT_PARAM *param );
extern void SendDataSPI( unsigned char data );
extern void StartSPI( void );
extern void StopSPI( void );
extern int  EnableSPIInt( unsigned char intSelect );
extern int  DisableSPIInt( unsigned char intSelect );
extern int  InitSPIInt( unsigned char intLevel );
extern int  isSPIInt( unsigned char intType );
extern unsigned char ReceiveDataSPI( void );


/// End status
#define SPI_NG						( 0 )			///< Failed
#define SPI_OK						( 1 )			///< Success
#define SPIINT_NOTOCCURRED			( 0 )			///< Not occurred
#define SPIINT_OCCURRED			( 1 )			///< Occurred

/// SPI Enable/Disable Select
#define SPICTLSPEN_ENABLE			( 1 )			///< Enable
#define SPICTLSPEN_DISABLE			( 0 )			///< Disable

/// SPI Clock Source Select
#define SPICTLMCLK_T8CH0			( 1 )			///< T8 ch.0

/// SPI First Mode Select
#define SPICTLMLSB_MSB				( 0 )			///< MSB
#define SPICTLMLSB_LSB				( 1 )			///< LSB

/// SPI Clock Phase Select
#define SPICTLCPHA_DATAOUT			( 1 )			///< Data Out

/// SPI Clock Polarity Select
#define SPICTLCPOL_ACTIVEL			( 1 )			///< Active L

/// SPI Master/Slave Select
#define SPICTLMSSL_SLAVE			( 0 )			///< Slave
#define SPICTLMSSL_MASTER			( 1 )			///< Master

/// SPI interrupt level
#define SPI_INTLVL_0				( 0 )			///< SPI interrupt level 0
#define SPI_INTLVL_1				( 1 )			///< SPI interrupt level 1
#define SPI_INTLVL_2				( 2 )			///< SPI interrupt level 2
#define SPI_INTLVL_3				( 3 )			///< SPI interrupt level 3
#define SPI_INTLVL_4				( 4 )			///< SPI interrupt level 4
#define SPI_INTLVL_5				( 5 )			///< SPI interrupt level 5
#define SPI_INTLVL_6				( 6 )			///< SPI interrupt level 6
#define SPI_INTLVL_7				( 7 )			///< SPI interrupt level 7

#endif	// SPI_H_
