/***************************************************************************
 *
 * @file	rfc_reg.h
 * @brief	Definition of the R/F Converter(RFC) Register.
 *
 * @par		Copyright:
 *			Copyright (C) SEIKO EPSON CORPORATION 2013-2014. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 22 Oct, 2013	1.00
 *				- First revision.
 *			- 27 Feb, 2014	1.0a
 *				- Modify.
 *
 **************************************************************************/

#ifndef	RFC_REG_H__
#define	RFC_REG_H__

#ifdef	__cplusplus
extern "C" {
#endif


/// RFC Clock Control Register.
typedef union RFC_CLK_REG_TAG {
	unsigned char			reg;
	struct RFC_CLK_REG_BIT_TAG {
		unsigned short		CLKEN		: 1;	///< These bits select the clock enable of the RFC.
		unsigned short		reserved_1	: 1;	///< Reserved.
		unsigned short		CLKSRC		: 1;	///< These bits select the clock source of the RFC.
		unsigned short		reserved_2	: 1;	///< Reserved.
		unsigned short		CLKDIV		: 2;	///< These bits select the division ratio of the RFC operating clock.
		unsigned short		reserved_3	: 2;	///< Reserved.
	} bit;
} RFC_CLK_REG;

/// RFC Control Register.
typedef union RFC_CTL_REG_TAG {
	unsigned short			reg;
	struct RFC_CTL_REG_BIT_TAG {
		unsigned short		RFCEN		: 1;
		unsigned short		reserved_1	: 5;
		unsigned short		EVTEN		: 1;
		unsigned short		CONEN		: 1;
		unsigned short		reserved_2	: 8;
	} bit;
	unsigned char byte_reg[2];
} RFC_CTL_REG;

/// RFC Oscillation Trigger Register.
typedef union RFC_TRG_REG_TAG {
	unsigned short			reg;
	struct RFC_TRG_REG_BIT_TAG {
		unsigned short		SREF		: 1;	///< This bit controls CR oscillation for the reference resistor.
		unsigned short		SSENA		: 1;	///< This bit controls CR oscillation for sensor A.
		unsigned short		SSENB		: 1;	///< This bit controls CR oscillation for sensor B.
		unsigned short		reserved_1	:13;	///< Reserved.
	} bit;
	unsigned char byte_reg[2];
} RFC_TRG_REG;

/// RFC Measurement Counter Low Register.
/// RFC Measurement Counter High Register.
typedef union RFC_MC_REG_TAG {
	unsigned long reg;
	struct RFC_MC_REG_BIT_TAG {
		unsigned long 		MC			:24;	///< Measurement counter data can be read and written through these bits.
		unsigned long		reserved_1	:8;		///< Reserved.
	} bit;
} RFC_MC_REG;

/// RFC Time Base Counter Low Register.
/// RFC Time Base Counter High Register.
typedef union RFC_TC_REG_TAG {
	unsigned long reg;
	struct RFC_TC_REG_BIT_TAG {
		unsigned long 		TC			:24;	///< Time base counter data can be read and written through these bits.
		unsigned long 		reserved_1	:8;		///< Reserved.
	} bit;
} RFC_TC_REG;

/// RFC Interrupt Mask Register.
typedef union RFC_IMSK_REG_TAG {
	unsigned short			reg;
	struct RFC_IMSK_REG_BIT_TAG {
		unsigned short		EREFIE		: 1;	///< This bit enable Reference oscillation completion interrupt.
		unsigned short		ESENAIE		: 1;	///< This bit enable Sensor A oscillation completion interrupt.
		unsigned short		ESENBIE		: 1;	///< This bit enable Sensor B oscillation completion interrupt.
		unsigned short		OVMCIE		: 1;	///< This bit enable Measurement counter overflow error interrupt.
		unsigned short		OVTCIE		: 1;	///< This bit enable Time base counter overflow error interrupt.
		unsigned short		reserved_1	:11;	///< Reserved.
	} bit;
	unsigned char byte_reg[2];
} RFC_IMSK_REG;

/// RFC Interrupt Flag Register.
typedef union RFC_IFLG_REG_TAG {
	unsigned short			reg;
	struct RFC_IFLG_REG_BIT_TAG {
		unsigned short		EREFIF		: 1;	///< This bit indicate Reference oscillation completion interrupt cause occurrence status.
		unsigned short		ESENAIF		: 1;	///< This bit indicate Sensor A oscillation completion interrupt cause occurrence status.
		unsigned short		ESENBIF		: 1;	///< This bit indicate Sensor B oscillation completion interrupt cause occurrence status.
		unsigned short		OVMCIF		: 1;	///< This bit indicate Measurement counter overflow error interrupt cause occurrence status.
		unsigned short		OVTCIF		: 1;	///< This bit indicate Time base counter overflow error interrupt cause occurrence status.
		unsigned short		reserved_1	:11;	///< Reserved.
	} bit;
	unsigned char byte_reg[2];
} RFC_IFLG_REG;

#ifdef __cplusplus
}
#endif

#endif	// RFC_REG_H__


