/****************************************************************************
 *
 * @file	t8.h
 * @brief	This is t8 driver header file for S1C17656.
 *
 * @par		Copyright:
 *			Copyright(C) SEIKO EPSON CORPORATION 2014-2014. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 2014/08/20	1.00
 *				- First revision
 *
 ***************************************************************************/

#ifndef _T8_H
#define _T8_H

extern int InitT8( unsigned short cntMode, unsigned short cntClk, unsigned short Count );
extern unsigned short GetT8Count( void );
extern void StartT8( void );
extern void StopT8( void );
extern int InitT8Int( unsigned char intLevel );
extern void EnableT8Int( void );
extern void DisableT8Int( void );
extern int isT8Int( void );
extern void ClrT8IntFlg( void );

/// End Status
#define T8_SET_NG				( 0x0 )		///< Fail
#define T8_SET_OK				( 0x1 )		///< Success

/// T8 Timer Run/Stop control
#define T8_STOP				( 0x0 )		///< stop
#define T8_RUN					( 0x1 )		///< run

/// T8 Interrupt Enable/Disable Select
#define T8_DISABLE				( 0x0 )		///< disable
#define T8_ENABLE				( 0x1 )		///< enable

/// T8 Interrupt Occurred/Not Occurred
#define T8_NOTOCCURRED			( 0x0 )		///< not occurred
#define T8_OCCURRED			( 0x1 )		///< occurred

/// T8 Count Mode Select
#define T8_REPEAT				( 0x0 )		///< repeat
#define T8_ONESHOT				( 0x1 )		///< one shot

/// T8 Timer Reset
#define T8_RESET				( 0x1 )		///< reset

/// T8 Count Clock Select
#define T8_CLOCK_DIV_1			( 0x0 )		///< PCLK  1/1
#define T8_CLOCK_DIV_2			( 0x1 )		///<       1/2
#define T8_CLOCK_DIV_4			( 0x2 )		///<       1/4
#define T8_CLOCK_DIV_8			( 0x3 )		///<       1/8
#define T8_CLOCK_DIV_16		( 0x4 )		///<       1/16
#define T8_CLOCK_DIV_32		( 0x5 )		///<       1/32
#define T8_CLOCK_DIV_64		( 0x6 )		///<       1/64
#define T8_CLOCK_DIV_128		( 0x7 )		///<       1/128
#define T8_CLOCK_DIV_256		( 0x8 )		///<       1/256
#define T8_CLOCK_DIV_512		( 0x9 )		///<       1/512
#define T8_CLOCK_DIV_1024		( 0xa )		///<       1/1024
#define T8_CLOCK_DIV_2048		( 0xb )		///<       1/2048
#define T8_CLOCK_DIV_4096		( 0xc )		///<       1/4096
#define T8_CLOCK_DIV_8192		( 0xd )		///<       1/8192
#define T8_CLOCK_DIV_16384		( 0xe )		///<       1/16384

/// T8 Interrupt Level Select
#define T8_INTLV_0				( 0x0 )		///< Interrupt Level 0
#define T8_INTLV_1				( 0x1 )		///< Interrupt Level 1
#define T8_INTLV_2				( 0x2 )		///< Interrupt Level 2
#define T8_INTLV_3				( 0x3 )		///< Interrupt Level 3
#define T8_INTLV_4				( 0x4 )		///< Interrupt Level 4
#define T8_INTLV_5				( 0x5 )		///< Interrupt Level 5
#define T8_INTLV_6				( 0x6 )		///< Interrupt Level 6
#define T8_INTLV_7				( 0x7 )		///< Interrupt Level 7

#endif	//_T8_H


