/****************************************************************************
 *
 * @file	main.c
 * @brief	This is svd-sample program for S1C17656 demonstration.
 *
 * @par		Copyright:
 *			Copyright(C) SEIKO EPSON CORPORATION 2014-2014. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 2014/08/20	1.00
 *				- First revision
 *
 ***************************************************************************/
/****************************************************************************
 * @mainpage	S1C17656 SVD
 *
 * @section		intro Introduction
 * Sample code compares power supply voltage by SVD,
 * and displays a result on the simulated I/O window.
 * @subsection	step1	Step 1: Start SVD.
 *						Starts the SVD.
 *						It waits for 500 microseconds.
 * @subsection	step2	Step 2: A result is displayed.
 * 						A result is decided on Simulated I/O.
 * @subsection	step3	Step 3: Stop SVD.
 *						Stops the SVD.
 *
 * @section		install Installation
 * Start the IDE and import the "s1c17656_svd" project.
 *
 ***************************************************************************/

/// #include
#include <string.h>
#include <stdio.h>
#include <c17656_reg.h>
#include <init.h>
#include <svd.h>

#define	WAIT_500u			(1000)
/// Prototype
int main(void);

/****************************************************************************
 * Main function.
 *
 * @brief	First,A MISC register is set up.
 *			Second,A SetSVDCompVolt function is called,
 *			A comparison voltage value is set up.
 *			Third,SVD is started.
 *			It waits for 500 microseconds.
 * 			Next,A result is displayed.
 *			then,SVD is stopped.
 *
 * @retval	SVD_SET_OK	Success.
 * @retval	SVD_SET_NG	Failed.
 ***************************************************************************/
int main(void)
{
	int				iRet;
	int				rnf_main = 1;

	DebugModeMisc( 0 );			/// Misc Stop in Debug Mode
	DebugModePsc( 0 );			/// Prescaler Stop in Debug Mode
	SetClockGear( 0 );			/// Set Clock Gear *default=0x0
	ControlClg( 3 );			/// Run Clg

	printf("<<< SVD demonstration start >>>\n");
	printf("<<< Comparison Voltage:3.20V >>>\n");

	iRet = SetSVDCompVolt(0x1a);
	if(iRet != 1){
		puts("***  SVD ERROR  ***\n");
		rnf_main = 0;
	} else {
		int				i;
		unsigned char	ucRet;

		SVD_CLK = 0x01;
		StartSVD();
		for( i = 0 ; i < 1000; i++ ){		/// Wait 500uSec
			asm ( "nop" );
		}
		ucRet = GetSVDResult();					/// Get SVD Detection Result
		if(ucRet){
			printf("<<< VDD is smaller than comparison voltage. >>>\n");
		} else {
			printf("<<< VDD is more than comparison voltage. >>>\n");
		}
		StopSVD();
	}
	printf("<<< SVD demonstration finish >>>\n");
	return ( rnf_main );
}
