/*******************************************************************************
 *
 * @file	svd.c
 * @brief	This is svd program for S1C17656 demonstration.
 *
 * @par		Copyright:
 * 			Copyright(C) SEIKO EPSON CORPORATION 2014-2014. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 2014/08/20	1.00
 *				- First revision
 *
 ******************************************************************************/

#include <svd.h>
#include <c17656_reg.h>
#include <svd_reg.h>

int SetSVDCompVolt(unsigned char select);
void StartSVD(void);
void StopSVD(void);
unsigned char GetSVDResult(void);

/****************************************************************************
 * SetSVDCompVolt function.
 *
 * @brief	First,The value of Argument select is checked.
 *			then, The argument select is set as a register.
 *
 * @param	select SVD Comparison Voltage Select Bits
 *
 * @retval	SVD_SET_OK	Success.
 * @retval	SVD_SET_NG	Failed.
 *
 ***************************************************************************/
int	SetSVDCompVolt(unsigned char select)
{
	int		iRet;

	/// Check Parameter
	if( (select < 0xe) || (select > 0x1a) ) {
		iRet =  0;
	} else {
		SVD_CMP = (SVD_CMP & 0xe0) | select;
		iRet =  1;
	}
	return iRet;
}
/****************************************************************************
 * StartSVD function.
 *
 * @brief	SVD is permitted.
 *
 ***************************************************************************/
void StartSVD(void)
{
	SVD_EN |= 0x01;
}
/****************************************************************************
 * StopSVD function.
 *
 * @brief	SVD is forbidden.
 *
 ***************************************************************************/
void StopSVD(void)
{
	SVD_EN &= 0xfe;
}
/****************************************************************************
 * GetSVDResult function.
 *
 * @brief	The detection result of power supply voltage is returned.
 *
 * @retval	The detection result of power supply voltage.
 *
 ***************************************************************************/
unsigned char GetSVDResult(void)
{

	return( SVD_RSLT );

}
