/****************************************************************************
 *
 * @file	t16a2.h
 * @brief	This is t16a2 driver header file for S1C17656.
 *
 * @par		Copyright:
 *			Copyright(C) SEIKO EPSON CORPORATION 2014-2014. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 2014/08/20	1.00
 *				- First revision
 *
 ***************************************************************************/

#ifndef _T16A2_H
#define _T16A2_H

typedef struct
{
	unsigned short		clkdiv;
	unsigned short		clksrc;
	unsigned short		hcm;
	unsigned short		cbufen;
	unsigned short		trmd;
	unsigned short		captrg;
	unsigned short		toutmd;
	unsigned short		toutinv;
	unsigned short		ccmd;
	unsigned short		dataA;
	unsigned short		dataB;

}T16A2_INIT_PARAM;


extern int InitT16A2( T16A2_INIT_PARAM *param);
extern void DataInitT16A2( T16A2_INIT_PARAM *param );
extern unsigned short GetT16A2Count( unsigned char cntType );
extern void StartT16A2(void);
extern void StopT16A2(void);
extern int InitT16A2Int( unsigned char intLevel );
extern int EnableT16A2Int( unsigned short intSelect );
extern int DisableT16A2Int( unsigned short intSelect );
extern int isT16A2Int( unsigned char cntType );
extern void ClrT16A2IntFlg( unsigned short intSelect );


/// T16A2 End Status
#define T16A2_SET_NG				( 0 )		///< Fail
#define T16A2_SET_OK				( 1 )		///< Success

/// T16A2 Count Clock Enable/Disable
#define T16A2_DISABLE				( 0 )		///< disable
#define T16A2_ENABLE				( 1 )		///< enable

/// T16A2 Count Mode Select
#define T16A2_REPEAT				( 0 )		///< repeat
#define T16A2_ONESHOT				( 1 )		///< one-shot

/// T16A2 TOUT Invert Select
#define T16A2_NORMAL				( 0 )		///< normal
#define T16A2_INVERT				( 1 )		///< invert

/// T16A2 Register Mode Select
#define T16A2_COMPARATOR			( 0 )		///< comparator
#define T16A2_CAPTURE				( 1 )		///< capture

/// T16A2 Counter Reset Control
#define T16A2_RESET				( 1 )		///< reset

/// T16A2 Counter Run/Stop
#define T16A2_STOP					( 0 )		///< stop
#define T16A2_RUN					( 1 )		///< run

/// T16A2 Interrupt Occurred/NotOccurred Select
#define T16A2_NOTOCCURRED			( 0 )		///< not occurred
#define T16A2_OCCURRED				( 1 )		///< occurred

/// T16A2 Clock Division Ratio Select
#define T16A2_CLKDIV_1				( 0x00 )	///< PCLK  1/1
#define T16A2_CLKDIV_2				( 0x01 )	///<       1/2
#define T16A2_CLKDIV_4				( 0x02 )	///<       1/4
#define T16A2_CLKDIV_8				( 0x03 )	///<       1/8
#define T16A2_CLKDIV_16			( 0x04 )	///<       1/16
#define T16A2_CLKDIV_32			( 0x05 )	///<       1/32
#define T16A2_CLKDIV_64			( 0x06 )	///<       1/64
#define T16A2_CLKDIV_128			( 0x07 )	///<       1/128
#define T16A2_CLKDIV_256			( 0x08 )	///<       1/256
#define T16A2_CLKDIV_512			( 0x09 )	///<       1/512
#define T16A2_CLKDIV_1024			( 0x0a )	///<       1/1024
#define T16A2_CLKDIV_2048			( 0x0b )	///<       1/2048
#define T16A2_CLKDIV_4096			( 0x0c )	///<       1/4096
#define T16A2_CLKDIV_8192			( 0x0d )	///<       1/8192
#define T16A2_CLKDIV_16384			( 0x0e )	///<       1/16384

/// T16A2 Count Clock Source Select
#define T16A2_CLKSRC_OSC3B			( 0 )		///< OSC3B
#define T16A2_CLKSRC_OSC1			( 1 )		///< OSC1

/// Halh clock mode
#define NORMALCLK_MODE				( 0 )		///< Normal clock mode
#define HALFCLK_MODE				( 1 )		///< Half clock mode

/// Capture trigger select
#define NONE_TRIGGER				( 0 )		///< None trigger
#define EDGE_UP					( 1 )		///< Up edge
#define EDGE_DOWN					( 2 )		///< Down edge
#define EDGE_UPANDDOWN				( 3 )		///< Up and down edge

/// TOUT mode select
#define OUTPUT_OFF					( 0 )		///< Output off
#define COMAUP_COMBDOWN			( 1 )		///< CompareA:up, CompareB:down
#define COMATGR_COMBNML			( 2 )		///< CompareA:toggle, CompareB:normal
#define COMANML_COMBTGR			( 3 )		///< CompareA:normal, CompareB:toggle

/// Get data select
#define NORMAL_CNTDATA				( 0 )		///< Normal count data
#define COMA_DATA			 		( 1 )		///< Compare A data
#define COMB_DATA					( 2 )		///< Compare B data

/// T16A2 Interrupt Level Select
#define T16A2_INTLVL_0				( 0 )		///< Interrupt Level 0
#define T16A2_INTLVL_1				( 1 )		///< Interrupt Level 1
#define T16A2_INTLVL_2				( 2 )		///< Interrupt Level 2
#define T16A2_INTLVL_3				( 3 )		///< Interrupt Level 3
#define T16A2_INTLVL_4				( 4 )		///< Interrupt Level 4
#define T16A2_INTLVL_5				( 5 )		///< Interrupt Level 5
#define T16A2_INTLVL_6				( 6 )		///< Interrupt Level 6
#define T16A2_INTLVL_7				( 7 )		///< Interrupt Level 7

/// PORT Advanced Timer Select
#define TOUTA_MODE					( 1 )		///< TOUTA (Compared Mode)
#define TOUTB_MODE					( 1 )		///< TOUTB (Compared Mode)

/// T16A2 Interrupt Enable/Disable
#define INT_COMA					( 0x01 )	///< Compare A Interrupt
#define INT_COMB					( 0x02 )	///< Compare B Interrupt
#define INT_CAPA					( 0x04 )	///< Capture A Interrupt
#define INT_CAPB					( 0x08 )	///< Capture B Interrupt
#define INT_CAPAOVE				( 0x10 )	///< Capture A OverWrite Interrupt
#define INT_CAPBOVE				( 0x20 )	///< Capture B OverWrite Interrupt
#define INT_MAX					( 0x3F )	///< interrupt max status



#endif	// _T16A2_H_
