/****************************************************************************
 *
 * @file	init.h
 * @brief	This is Header file for init function.
 *
 * @par		Copyright:
 *			Copyright(C) SEIKO EPSON CORPORATION 2014-2014. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 2014/08/20	1.00
 *				- First revision
 *
 ***************************************************************************/

#ifndef _INIT_H
#define _INIT_H

extern void DebugModePsc(unsigned char debugMode);
extern void ControlClg(unsigned char control);
extern void SetClockGear(unsigned char gear);
extern void SetFlashcAccessCycle(unsigned char flashc);
extern void DebugModeMisc(unsigned char debugMode);
extern void ProtectMisc(unsigned char protectCode);
extern void SetMiscIramSize(unsigned char iramSize);
extern void SetMiscVecAddress(unsigned long baseAdrr);

/// Prescaler run/stop Select in Debug Mode
#define MISC_O1DBG_STOP		( 0x0 )     ///< Stop control in debug mode(PCLK)
#define MISC_O1DBG_RUN   	   	( 0x1 )     ///< Run control in debug mode(PCLK)

/// CLG run/stop Select
#define CLG_PCLK_DISABLE      	( 0x0 )     ///< PCLK disable
#define CLG_PCLK_ENABLE       	( 0x3 )     ///< PCLK enable

///  Clock Gear Select
#define CLG_CCLKGR_DIV_1   	( 0x0 )     ///< Clock Gear ratio 1
#define CLG_CCLKGR_DIV_2   	( 0x1 )     ///< Clock Gear ratio 2
#define CLG_CCLKGR_DIV_4   	( 0x2 )     ///< Clock Gear ratio 4
#define CLG_CCLKGR_DIV_8   	( 0x3 )     ///< Clock Gear ratio 8

/// Flash Access Cycle Select
#define FLASHC_WAIT_NO			( 0x0 )		///< Flashc Read Wait Cycle NO
#define FLASHC_WAIT_1			( 0x1 )		///< Flashc Read Wait Cycle 1
#define FLASHC_WAIT_2			( 0x2 )		///< Flashc Read Wait Cycle 2
#define FLASHC_WAIT_3			( 0x3 )		///< Flashc Read Wait Cycle 3

/// OSC1 Peripheral Select in Debug Mode
#define MISC_O2DBG_STOP		( 0x0 )     ///< Stop control in debug mode(Except PCLK Peripheral Circuits)
#define MISC_O2DBG_RUN   	   	( 0x1 )     ///< Run control in debug mode(Except PCLK Peripheral Circuits)

/// Misc register write protect mode Select
#define MISC_PROTECT_ON		( 0x0 )		///< Set the write protect
#define MISC_PROTECT_OFF		( 0x96 )	///< Remove the write protect

/// Iram Size Select
#define MISC_IRAM_2KB			( 0x3 )		///< Iram size 2kb
#define MISC_IRAM_1KB			( 0x4 )		///< Iram size 1kb
#define MISC_IRAM_512B			( 0x5 )		///< Iram size 512b

#endif	// _INIT_H


