/********************************************************************************
 *
 * @file	main.c
 * @brief	This is uart(master)-sample program for S1C17656 demonstration.
 *
 * @par		Copyright:
 *			Copyright(C) SEIKO EPSON CORPORATION 2014-2014. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 2014/08/20	1.00
 *				- First revision
 *
 *******************************************************************************/
/********************************************************************************
 * @mainpage	S1C17656 UART(MASTER)
 *
 * @section		intro Introduction
 * Sample code transmit data using UART.
 * The code receive data using UART.
 *
 * @subsection	step1	Step 1: Start UART.
 *						Start UART.
 *						Initialize UART transmission rate 222222bps, data length 8bits,
 *						stop bit 1bit, non parity.
 * @subsection	step2	Step 2: Transmit "0x7F" and Receive "0x7F".
 * 						Receive "0x7F" after transmit "0x7F".
 * @subsection	step3	Step 3: Transmit "0x21 - 0x7E" and Receive "0x21 - 0x7E".
 * 						Receive "0x21 - 0x7E" after transmit "0x21 - 0x7E".
 * @subsection	step4	Step 4: Display data.
 *						Receive data from UART port, display to simulated I/O window.
 *
 * @section		install Installation
 * Start the IDE and import the "s1c17656_uart_mst" project.
 *
 *******************************************************************************/

/// #include
#include <stdio.h>
#include <c17656_reg.h>
#include <init.h>
#include <uart.h>
#include <clg.h>
#include <ct.h>

/// Prototype
int main(void);
void IntUART(void)__attribute__ ((interrupt_handler));
void IntCT(void)__attribute__ ((interrupt_handler));

/// Definition
#define CONNECT_DATA					( 0x7F )		///< Connect data
#define CT_INT_XHZ						CT_INT_1HZ
#define CONNECT_DATA_SEND_OFF			( 0 )
#define CONNECT_DATA_SEND_ON			( 1 )
#define UART_ST_MASK					( 0xff )
#define WAIT_8Cycle					(8)


/// Global
unsigned char strData[] =
{
       0x21, 0x22, 0x23, 0x24, 0x25, 0x26, 0x27, 0x28, 0x29, 0x2A, 0x2B, 0x2C, 0x2D, 0x2E, 0x2F,
 0x30, 0x31, 0x32, 0x33, 0x34, 0x35, 0x36, 0x37, 0x38, 0x39, 0x3A, 0x3B, 0x3C, 0x3D, 0x3E, 0x3F,
 0x40, 0x41, 0x42, 0x43, 0x44, 0x45, 0x46, 0x47, 0x48, 0x49, 0x4A, 0x4B, 0x4C, 0x4D, 0x4E, 0x4F,
 0x50, 0x51, 0x52, 0x53, 0x54, 0x55, 0x56, 0x57, 0x58, 0x59, 0x5A, 0x5B, 0x5C, 0x5D, 0x5E, 0x5F,
 0x60, 0x61, 0x62, 0x63, 0x64, 0x65, 0x66, 0x67, 0x68, 0x69, 0x6A, 0x6B, 0x6C, 0x6D, 0x6E, 0x6F,
 0x70, 0x71, 0x72, 0x73, 0x74, 0x75, 0x76, 0x77, 0x78, 0x79, 0x7A, 0x7B, 0x7C, 0x7D, 0x7E, '\0'
};
volatile unsigned int strCount = 0;
volatile unsigned int receiveCount = 0;
volatile int sendWait;
unsigned char receiveData[sizeof(strData)];
unsigned int  DataLen = sizeof(strData);

/// End Status
volatile int rnf;
volatile int rnf_main = 1;
/****************************************************************************
 * Main function.
 *
 * @retval	1	Normality
 * @retval	0	Abnormality
 ***************************************************************************/
int main(void)
{
	/// Initial Parameter
	UART_INIT_PARAM param;
	int				i,n;

	param.dataLen = 1;		/// character length
	param.parity = 0;		/// parity mode
	param.stopBit = 0;		/// stop bit
	param.recByte = 0;		/// receive buffer full int. condition setup
	param.div = 0;			/// clock division ratio
	param.clock = 0;		/// clock source(OSC3B)
	param.brr = 0x00;		/// baud rate count(OSC3B)
	param.fmd = 0x2;		/// fine mode(OSC3B)

	asm ( "di" );

	DebugModeMisc( 0 );		/// Misc Stop in Debug Mode
	DebugModePsc( 0 );		/// Prescaler Stop in Debug Mode
	SetClockGear( 0 );		/// Set Clock Gear *default=0x0
	ControlClg( 3 );		/// Run Clg

	/// Start OSC3B 4MHz
	rnf = StartOSC3B(3);
	if(rnf == 0){
		printf("***  StartOSC3B ERROR  ***\n");
		rnf_main = 0;
	}

	///Start OSC1
	CLG_WAIT = 0x2;						/// Wait 4096 cycle
	CLG_CTL |= 0x2;						/// Start OSC1
	for( i = 0 ; i < 122; i++ ){		/// Wait 4096 * 4000000/32768 Cycle
		for( n = 0 ; n < 4096; n++ ){
			asm ( "nop" );
		}
	}

	/// Initialize UART
	rnf = InitUART( &param );
	if( rnf == 0 ){
		printf("***  InitUART ERROR  ***\n");
		rnf_main = 0;
	}
	/// Initialize UART interruption
	rnf = InitUARTInt( 3 );
	if( rnf == 0 ){
		printf("***  InitUARTInt ERROR  ***\n");
		rnf_main = 0;
	}
	rnf = EnableUARTInt( 0xE0 );
	if( rnf == 0 ){
		printf("***  EnableUARTInt ERROR  ***\n");
		rnf_main = 0;
	}
	/// UART Start
	StartUART();

	/// Reset counter
	ResetCTCount();
	/// CT Initialize interrupt
	rnf = InitCTInt( 3 );
	if( rnf == 0 ){
		printf("***  InitCTInt ERROR  ***\n");
		rnf_main = 0;
	}
	/// CT Interrupt enable
	rnf = EnableCTInt( 0x1 );
	if( rnf == 0 ){
		puts("***  EnableCTInt ERROR  ***\n");
		rnf_main = 0;
	}
	/// Start CT
	StartCT();

	printf( "<<< UART OSC3B demonstration start >>>\n" );
	printf( "waiting connection.\n" );

	strCount = DataLen + 1;					///0x7F Send Request
	sendWait = 1;
	asm ( "ei" );
/** Transmit "0x7F" and Receive "0x7F" **/
	while(1){
		if(receiveCount){
			asm("di");
			receiveCount = 0;
			if(receiveData[receiveCount] == 0x7F){
				break;
			}
			asm("ei");
		}
		if( sendWait == 1 ){
			sendWait = 0;
			SendDataUART( 0x7F );
		}
	}
	asm("ei");
	while( 1 ){
		if( (UART_ST0 & 0xff) == 1 ){
			break;
		}
	}
	strCount = 0;
	receiveCount = 0;
	SendDataUART( strData[strCount++] );
	/// Wait till all data transmit.
	while( 1 ){
		if( strCount >= DataLen ){
			break;
		}
	}
	/// Wait till all data receive.
	while( 1 ){
		if( (receiveCount >= DataLen) ){
			break;
		}
	}
/*****/
	/// UART interrupt disable
	rnf = DisableUARTInt( 0xE0 );
	if( rnf == 0 ){
		printf("***  DisableUARTInt ERROR  ***\n");
		rnf_main = 0;
	}

	/// Stop UART
	StopUART();

	printf( "***receive data***\n" );
	printf( "%s\n", receiveData );
	printf( "<<< UART OSC3B demonstration finish >>>\n" );

	return ( rnf_main );
}

/****************************************************************************
 * IntUART function.
 *
 * @brief	 UART interrupt routine.
 ***************************************************************************/
void IntUART(void)
{
	/// Check transmit interrupt occurred
	if ( UART_CTL0_TEIEN ){
		if( UART_ST0_TRED == 1 ){
			UART_ST0 = 0x80;
			/// Write transmit data (string data(0x21-0x7E))
			if ( strCount < DataLen ){
				SendDataUART( strData[strCount++] );
			}
		}
	}
	/// Check receive interrupt occurred
	if ( UART_CTL0_RIEN ){
		/// Check error( framing, parity and overrun error )
		if( isUARTInt(0x70) == 1 ){
			/// Clear interrupt flag
			rnf = ClrUARTIntFlg( 0x70 );
			if( rnf == 0 ){
				rnf_main = 0;
			}
		}
		/// Check receive data ready flag
		if ( UART_ST0_RDRY == 1){
			unsigned char ucBuf_1;

			/// Get receive data
			ucBuf_1 = ReceiveDataUART();
			/// Read receive data
			receiveData[receiveCount++] = ucBuf_1;
		}
	}

}

/****************************************************************************
 * IntCT function.
 *
 * @brief	CT interrupt routine.
 ***************************************************************************/
void IntCT(void)
{

	if( isCTInt(0x01) ){
		int ret;

		/// Clear interrupt flag
		ret = ClrCTIntFlg( 0x01 );
		if( ret == 1 ){
			sendWait = 1;
		}
	}
}



