/***************************************************************************
 *
 * @file	lcd_reg.h
 * @brief	This is Bit field for LCD register.
 *
 * @par		Copyright:
 *			Copyright (C) SEIKO EPSON CORPORATION 2013-2014. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 22 Oct, 2013	1.00
 *				- First revision.
 *			- 27 Feb, 2014	1.0a
 *				- Modify.
 *
 **************************************************************************/

#ifndef	LCD_REG_H__
#define	LCD_REG_H__

#ifdef	__cplusplus
extern "C" {
#endif


/// LCD Timing Clock Select Register.
typedef union LCD_TCLK_REG_TAG {
	unsigned char			reg;
	struct LCD_TCLK_REG_BIT_TAG {
		unsigned short		LCDTCLKE	: 1;
		unsigned short		reserved_1	: 1;
		unsigned short		LCDTCLKSRC	: 2;
		unsigned short		LCDTCLKD	: 2;
		unsigned short		reserved_2	: 2;
	} bit;
} LCD_TCLK_REG;

/// LCD Booster Clock Control Register.
typedef union LCD_BCLK_REG_TAG {
	unsigned char			reg;
	struct LCD_BCLK_REG_BIT_TAG {
		unsigned short		LCDBCLKE	: 1;
		unsigned short		reserved_1	: 1;
		unsigned short		LCDBCLKSRC	: 2;
		unsigned short		LCDBCLKD	: 3;
		unsigned short		reserved_2	: 1;
	} bit;
} LCD_BCLK_REG;

/// LCD Display Control Register.
typedef union LCD_DCTL_REG_TAG {
	unsigned char			reg;
	struct LCD_DCTL_REG_BIT_TAG {
		unsigned short		DSPC		: 2;
		unsigned short		reserved_1	: 2;
		unsigned short		DSPREV		: 1;
		unsigned short		reserved_2	: 3;
	} bit;
} LCD_DCTL_REG;

/// LCD Clock Control Register.
typedef union LCD_CCTL_REG_TAG {
	unsigned char			reg;
	struct LCD_CCTL_REG_BIT_TAG {
		unsigned short		LDUTY		: 3;
		unsigned short		reserved_1	: 3;
		unsigned short		FRMCNT		: 2;
	} bit;
} LCD_CCTL_REG;

/// LCD Voltage Regulator Control Register.
typedef union LCD_VREG_REG_TAG {
	unsigned char			reg;
	struct LCD_VREG_REG_BIT_TAG {
		unsigned short		VCSEL		: 1;
		unsigned short		reserved_1	: 3;
		unsigned short		LHVLD		: 1;
		unsigned short		reserved_2	: 3;
	} bit;
} LCD_VREG_REG;

/// LCD Interrupt Mask Register.
typedef union LCD_IMSK_REG_TAG {
	unsigned char			reg;
	struct LCD_IMSK_REG_BIT_TAG {
		unsigned short		IFRMEN		: 1;
		unsigned short		reserved_1	: 7;
	} bit;
} LCD_IMSK_REG;

/// LCD Interrupt Flag Register.
typedef union LCD_IFLG_REG_TAG {
	unsigned char			reg;
	struct LCD_IFLG_REG_BIT_TAG {
		unsigned short		IFRMFLG		: 1;
		unsigned short		reserved_1	: 7;
	} bit;
} LCD_IFLG_REG;


#ifdef __cplusplus
}
#endif

#endif	// LCD_REG_H__


