/***************************************************************************
 *
 * @file	t16a2_reg.h
 * @brief	This is Bit field for T16A2 register.
 *
 * @par		Copyright:
 *			Copyright (C) SEIKO EPSON CORPORATION 2013-2014. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 22 Oct, 2013	1.00
 *				- First revision.
 *			- 27 Feb, 2014	1.0a
 *				- Modify.
 *
 **************************************************************************/

#ifndef T16A2_REG_H__
#define T16A2_REG_H__


#ifdef	__cplusplus
extern "C" {
#endif


/// Advanced Timer Clock Control Register.
typedef union T16A_CLKN_REG_TAG {
	unsigned char			reg;
	struct T16A_CLKN_REG_BIT_TAG {
		unsigned short		T16ACLKE	: 1;
		unsigned short		reserved_1	: 1;
		unsigned short		T16ACLKSRC	: 2;
		unsigned short		T16ACLKD	: 4;
	} bit;
} T16A_CLKN_REG;

/// Advanced Timer Control Register.
typedef union T16A_CTLN_REG_TAG {
	unsigned short			reg;
	struct T16A_CTLN_REG_BIT_TAG {
		unsigned short		PRUN		: 1;
		unsigned short		PRESET		: 1;
		unsigned short		TRMD		: 1;
		unsigned short		CBUFEN		: 1;
		unsigned short		reserved_1	: 2;
		unsigned short		HCM			: 1;
		unsigned short		reserved_2	: 9;
	} bit;
	unsigned char byte_reg[2];
} T16A_CTLN_REG;

/// Advanced Timer Counter Data Register.
typedef union T16A_TCN_REG_TAG {
	unsigned short			reg;
} T16A_TCN_REG;

/// Advanced Timer Comparator/Capture Control Register.
typedef union T16A_CCCTLN_REG_TAG {
	unsigned short			reg;
	struct T16A_CCCTLN_REG_BIT_TAG {
		unsigned short		CCAMD		: 1;
		unsigned short		TOUTAINV	: 1;
		unsigned short		reserved_1	: 2;
		unsigned short		TOUTAMD		: 2;
		unsigned short		CAPATRG		: 2;
		unsigned short		CCBMD		: 1;
		unsigned short		TOUTBINV	: 1;
		unsigned short		reserved_2	: 2;
		unsigned short		TOUTBMD		: 2;
		unsigned short		CAPBTRG		: 2;
	} bit;
	unsigned char byte_reg[2];
} T16A_CCCTLN_REG;

/// Advanced Timer Comparator/Capture A Data Register.
/// Advanced Timer Comparator/Capture B Data Register.
typedef union T16A_CCXN_REG_TAG {
	unsigned short			reg;
} T16A_CCXN_REG;

/// Advanced Timer Comparator/Capture Interrupt Enable Register.
typedef union T16A_IENN_REG_TAG {
	unsigned short			reg;
	struct T16A_IENN_REG_BIT_TAG {
		unsigned short		CAIE		: 1;
		unsigned short		CBIE		: 1;
		unsigned short		CAPAIE		: 1;
		unsigned short		CAPBIE		: 1;
		unsigned short		CAPAOWIE	: 1;
		unsigned short		CAPBOWIE	: 1;
		unsigned short		reserved_1	: 10;
	} bit;
	unsigned char byte_reg[2];
} T16A_IENN_REG;

/// Advanced Timer Comparator/Capture Interrupt Flag Register.
typedef union T16A_IFLGN_REG_TAG {
	unsigned short			reg;
	struct T16A_IFLGN_REG_BIT_TAG {
		unsigned short		CAIF		: 1;
		unsigned short		CBIF		: 1;
		unsigned short		CAPAIF		: 1;
		unsigned short		CAPBIF		: 1;
		unsigned short		CAPAOWIF	: 1;
		unsigned short		CAPBOWIF	: 1;
		unsigned short		reserved_1	: 10;
	} bit;
	unsigned char byte_reg[2];
} T16A_IFLGN_REG;


#ifdef __cplusplus
}
#endif

#endif	// T16A2_REG_H__


