/***************************************************************************
 *
 * @file	uart_reg.h
 * @brief	Definition of the UART Register.
 *
 * @par		Copyright:
 *			Copyright (C) SEIKO EPSON CORPORATION 2013. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 22 Oct, 2013	1.00
 *				- First revision.
 *
 **************************************************************************/

#ifndef	UART_REG_H__
#define	UART_REG_H__

#ifdef	__cplusplus
extern "C" {
#endif


/// UART Status Register.
typedef union UART_STN_REG_TAG {
	unsigned char			reg;
	struct UART_STN_REG_BIT_TAG {
		unsigned short		TDBE		: 1;
		unsigned short		RDRY		: 1;
		unsigned short		TRBS		: 1;
		unsigned short		RD2B		: 1;
		unsigned short		OER			: 1;
		unsigned short		PER			: 1;
		unsigned short		FER			: 1;
		unsigned short		TRED		: 1;
	} bit;
} UART_STN_REG;

/// UART Ch.0 Transmit Data Register.
typedef union UART_TXDN_REG_TAG {
	unsigned char			reg;
} UART_TXDN_REG;

/// UART Ch.0 Receive Data Register.
typedef union UART_RXDN_REG_TAG {
	unsigned char			reg;
} UART_RXDN_REG;

/// UART Ch.0 Mode Register.
typedef union UART_MODN_REG_TAG {
	unsigned char			reg;
	struct UART_MODN_REG_BIT_TAG {
		unsigned short		reserved_1	: 1;
		unsigned short		STPB		: 1;
		unsigned short		PMD			: 1;
		unsigned short		PREN		: 1;
		unsigned short		CHLN		: 1;
		unsigned short		reserved_2	: 3;
	} bit;
} UART_MODN_REG;

/// UART Ch.0 Control Register.
typedef union UART_CTLN_REG_TAG {
	unsigned char			reg;
	struct UART_CTLN_REG_BIT_TAG {
		unsigned short		RXEN		: 1;
		unsigned short		RBFI		: 1;
		unsigned short		reserved_1	: 2;
		unsigned short		TIEN		: 1;
		unsigned short		RIEN		: 1;
		unsigned short		REIEN		: 1;
		unsigned short		TEIEN		: 1;
	} bit;
} UART_CTLN_REG;

/// UART Ch.0 Expansion Register.
typedef union UART_EXPN_REG_TAG {
	unsigned char			reg;
	struct UART_EXPN_REG_BIT_TAG {
		unsigned short		IRMD		: 1;
		unsigned short		reserved_1	: 7;
	} bit;
} UART_EXPN_REG;

/// UART Ch.0 Baud Rate Register.
typedef union UART_BRN_REG_TAG {
	unsigned char			reg;
} UART_BRN_REG;

/// UART Ch.0 Fine Mode Register.
typedef union UART_FMDN_REG_TAG {
	unsigned char			reg;
	struct UART_FMDN_REG_BIT_TAG {
		unsigned short		FMD			: 4;
		unsigned short		reserved_1	: 4;
	} bit;
} UART_FMDN_REG;

/// UART Ch.0 Clock Control Register.
typedef union UART_CLKN_REG_TAG {
	unsigned char			reg;
	struct UART_CLKN_REG_BIT_TAG {
		unsigned short		UTCLKE		: 1;
		unsigned short		reserved_1	: 1;
		unsigned short		UTCLKSRC	: 2;
		unsigned short		UTCLKD		: 2;
		unsigned short		reserved_2	: 2;
	} bit;
} UART_CLKN_REG;


#ifdef __cplusplus
}
#endif

#endif	// UART_REG_H__


