/****************************************************************************
 *
 * @file	uart.h
 * @brief	This is uart driver header file for S1C17656.
 *
 * @par		Copyright:
 *			Copyright(C) SEIKO EPSON CORPORATION 2014-2014. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 2014/08/20	1.00
 *				- First revision
 *
 ***************************************************************************/

#ifndef _UART_H
#define _UART_H

typedef struct
{
	unsigned char		dataLen;
	unsigned char		parity;
	unsigned char		stopBit;
	unsigned char		recByte;
	unsigned char		clock;
	unsigned char		div;
	unsigned char		brr;
	unsigned char		fmd;

}UART_INIT_PARAM;

extern int  InitUART( UART_INIT_PARAM *param );
extern void SendDataUART( unsigned char data );
extern void StartUART( void );
extern void StopUART( void );
extern int  EnableUARTInt( unsigned char intSelect );
extern int  DisableUARTInt( unsigned char intSelect );
extern int  InitUARTInt( unsigned char intLevel );
extern int  isUARTInt( unsigned char intType );
extern int  ClrUARTIntFlg( unsigned char intType );
extern unsigned char ReceiveDataUART( void );


/// End Status
#define UART_NG					( 0 )			///< Failed
#define UART_OK					( 1 )			///< Success
#define UARTINT_NOTOCCURRED		( 0 )			///< Not occurred
#define UARTINT_OCCURRED		    ( 1 )			///< Occurred

/// UART Enable/Disable Select
#define UARTCTLRXEN_DISABLE		( 0 )			///< Disable
#define UARTCTLRXEN_ENABLE			( 1 )			///< Enable

/// UART Count Clock Enable/Disable Select
#define UARTCLKUTCLKE_DISABLE		( 0 )			///< Disable
#define UARTCLKUTCLKE_ENABLE		( 1 )			///< Enable

/// Parity Select
#define UARTMODPREN_NOPARITY		( 0 )			///< No Parity
#define UARTMODPREN_WITHPARITY		( 1 )			///< With Parity
#define UARTMODPMD_EVEN			( 0 )			///< Even
#define UARTMODPMD_ODD				( 1 )			///< Odd

/// Character Length Select
#define UARTMODCHLN_8BITS			( 1 )			///< 8Bits

/// Stop Bit Select
#define UARTMODSTPB_1BIT			( 0 )			///< 1Bit
#define UARTMODSTPB_2BITS			( 1 )			///< 2Bits

/// Receive Buffer Full Interrupt Condition Setup
#define UARTCTLRBFI_1BYTE			( 0 )			///< 1Byte
#define UARTCTLRBFI_2BYTES			( 1 )			///< 2Bytes

/// End of Transmission Flag
#define UARTSTTRED_COMPLETED		( 1 )			///< Completed

/// Receive Data Ready Flag
#define UARTSTRDRY_READY			( 1 )			///< Ready

/// Clock source select
#define UARTSRC_OSC3B				( 0 )			///< OSC3B
#define UARTSRC_OSC1				( 1 )			///< OSC1
#define UARTSRC_EXTRNLCLK			( 3 )			///< External clock

/// UART Clock Division Ratio
#define UARTCLKDIV_1				( 0 )			///< 1/1
#define UARTCLKDIV_2				( 1 )			///< 1/2
#define UARTCLKDIV_4				( 2 )			///< 1/4
#define UARTCLKDIV_8				( 3 )			///< 1/8

/// UART Interrupt Select
#define UARTINT_TIEN				( 0x10 )		///< Transmit buffer empty interrupt
#define UARTINT_RIEN				( 0x20 )		///< Receive buffer full interrupt
#define UARTINT_REIEN				( 0x40 )		///< Receive error interrupt
#define UARTINT_TEIEN				( 0x80 )		///< End of transmission interrupt

/// UART interrupt level
#define UART_INTLVL_0				( 0 )			///< UART interrupt level 0
#define UART_INTLVL_1				( 1 )			///< UART interrupt level 1
#define UART_INTLVL_2				( 2 )			///< UART interrupt level 2
#define UART_INTLVL_3				( 3 )			///< UART interrupt level 3
#define UART_INTLVL_4				( 4 )			///< UART interrupt level 4
#define UART_INTLVL_5				( 5 )			///< UART interrupt level 5
#define UART_INTLVL_6				( 6 )			///< UART interrupt level 6
#define UART_INTLVL_7				( 7 )			///< UART interrupt level 7

#define UARTPARTY_NOPARTY			( 0 )			///< No Parity
#define UARTPARTY_ODDPARTY			( 1 )			///< Odd
#define UARTPARTY_EVENPARTY		( 2 )			///< Even

/// Transmit data buffer empty data
#define	UARTSTTDBE_EMPTY		( 1 )			///< Empty

/// Receive data ready data
#define UART_IS_NOT_FULL			( 0 )			///< UART is not full now
#define UART_IS_FULL				( 1 )			///< UART is full now


#endif	// _UART_H


