/***************************************************************************
 *
 * @file	t8_reg.h
 * @brief	This is Bit field for T8 register.
 *
 * @par		Copyright:
 *			Copyright (C) SEIKO EPSON CORPORATION 2013. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 22 Oct, 2013	1.00
 *				- First revision.
 *
 **************************************************************************/

#ifndef T8_REG_H__
#define T8_REG_H__

#ifdef	__cplusplus
extern "C" {
#endif


/// 8-bit Timer Ch.x Input Clock Select Register.
typedef union T8_CLKN_REG_TAG {
	unsigned short			reg;
	struct T8_CLKN_REG_BIT_TAG {
		unsigned short		DF			: 4;
		unsigned short		reserved_1	: 12;
	} bit;
	unsigned char byte_reg[2];
} T8_CLKN_REG;

/// 8-bit Timer Ch.x Reload Data Register.
typedef union T8_TRN_REG_TAG {
	unsigned short			reg;
	struct T8_TRN_REG_BIT_TAG {
		unsigned short		TR			: 8;
		unsigned short		reserved_1	: 8;
	} bit;
	unsigned char byte_reg[2];
} T8_TRN_REG;

/// 8-bit Timer Ch.x Counter Data Register.
typedef union T8_TCN_REG_TAG {
	unsigned short			reg;
	struct T8_TCN_REG_BIT_TAG {
		unsigned short		TC			: 8;
		unsigned short		reserved_1	: 8;
	} bit;
	unsigned char byte_reg[2];
} T8_TCN_REG;

/// 8-bit Timer Ch.x Control Register.
typedef union T8_CTLN_REG_TAG {
	unsigned short			reg;
	struct T8_CTLN_REG_BIT_TAG {
		unsigned short		PRUN		: 1;
		unsigned short		PRESER		: 1;
		unsigned short		reserved_1	: 2;
		unsigned short		TRMD		: 1;
		unsigned short		reserved_2	: 11;
	} bit;
	unsigned char byte_reg[2];
} T8_CTLN_REG;

/// 8-bit Timer Ch.x Interrupt Control Register.
typedef union T8_INTN_REG_TAG {
	unsigned short			reg;
	struct T8_INTN_REG_BIT_TAG {
		unsigned short		T8IF		: 1;
		unsigned short		reserved_1	: 7;
		unsigned short		T8IE		: 1;
		unsigned short		reserved_2	: 7;
	} bit;
	unsigned char byte_reg[2];
} T8_INTN_REG;


#ifdef __cplusplus
}
#endif

#endif	// T8_REG_H__


