/****************************************************************************
 *
 * @file	clg.h
 * @brief	This is clg(osc) driver header file for S1C17656.
 *
 * @par 	Copyright:
 *			Copyright(C) SEIKO EPSON CORPORATION 2014-2014. All rights reserved.
 *
 * @warning -
 *
 * @par 	History:
 *			- 2014/08/20	1.00
 *				- First revision
 *
 ***************************************************************************/

#ifndef _CLG_H
#define _CLG_H

extern int	StopOSC1( void );
extern int	StartOSC1( void );
extern int	StopOSC3B( void );
extern int	StartOSC3B( unsigned char osc3Frq );
extern int	SetWaitCycleClg( unsigned char oscType , unsigned char waitCycle );
extern int	ChgOSC( unsigned char chgOscType );


/// End Status
#define CLG_STOP_NG 				( 0 )		///< Fail
#define CLG_STOP_OK 				( 1 )		///< Success
#define CLG_START_NG				( 0 )		///< Fail
#define CLG_START_OK				( 1 )		///< Success
#define CLG_SET_NG					( 0 )		///< Fail
#define CLG_SET_OK					( 1 )		///< Success

/// OSC3B Frequency Select
#define OSC3B_FRQ_4M				( 3 )		///< 4MHz
#define OSC3B_FRQ_2M				( 0 )		///< 2MHz
#define OSC3B_FRQ_1M				( 1 )		///< 1MHz
#define OSC3B_FRQ_500K				( 2 )		///< 500kHz

/// OSC Wait Source Select
#define OSC_WAITSRC_OSC1A			( 0 )		///< OSC Source OSC1
#define OSC_WAITSRC_OSC3B			( 3 )		///< OSC Source OSC3B

/// Wait Cycle Select
#define WAIT_CYCLE_00				( 0 )		///< 16384/64/1024/64 cycles(OSC1A/ OSC1B/ OSC3A/ OSC3B)
#define WAIT_CYCLE_01				( 1 )		///< 8192/32/512/32 cycles(OSC1A/ OSC1B/ OSC3A/ OSC3B)
#define WAIT_CYCLE_02				( 2 )		///< 4096/16/256/16 cycles(OSC1A/ OSC1B/ OSC3A/ OSC3B)
#define WAIT_CYCLE_03				( 3 )		///< 2048/8/128/8 cycles(OSC1A/ OSC1B/ OSC3A/ OSC3B)

/// Change Clock Select
#define CHG_OSC3B_OSC1A 			( 2 )		///< Change to OSC1
#define CHG_OSC1_OSC3B				( 3 )		///< Change to OSC3B

#endif	// _CLG_H
