/****************************************************************************
 *
 * @file	wdt.c
 * @brief	This is wdt driver program file for S1C17656.
 *
 * @par		Copyright:
 *			Copyright(C) SEIKO EPSON CORPORATION 2014-2014. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 2014/08/20	1.00
 *				- First revision
 *
 ***************************************************************************/

#include <c17656_reg.h>
#include <wdt.h>

/****************************************************************************
 * InitWDT function.
 *
 * @brief	Initialize WDT.
 *
 * @param	mode
 *	@li @c		WDT_NMI		NMI status
 *	@li @c		WDT_RESET	Reset
 *
 * @retval	WDT_SET_NG		Failed
 * @retval	WDT_SET_OK		Success
 ***************************************************************************/
int InitWDT(unsigned char mode)
{
	/// Check parameter
	if( mode > 1 ){
		return 0;
	}

	/// WDT mode set
	WDT_ST = (mode << 1);

	return 1;
}

/*****************************************************************************
 * StartWDT function.
 *
 * @brief	Start WDT.
 ***************************************************************************: */
void StartWDT(void)
{
	/// WDT RESET
	/// WDT RUN
	WDT_CTL = 0x10;
}

/*****************************************************************************
 * StopWDT function.
 *
 * @brief	Stop WDT.
 ***************************************************************************: */
void StopWDT(void)
{
	/// WDT RESET
	ResetWDT();

	/// WDT STOP
	WDT_CTL = 0x0a;
}

/*****************************************************************************
 * ResetWDT function.
 *
 * @brief	Reset WDT.
 ***************************************************************************: */
void ResetWDT(void)
{
	/// WDT RESET
	WDT_CTL |= 0x10;
}

/****************************************************************************
 * isWDTnmi function.
 *
 * @brief	Check NMI status.
 *
 * @retval	WDT_NOTOCCURRED		Not occurred
 * @retval	WDT_OCCURRED		Occurred
 ***************************************************************************/
int isWDTnmi(void)
{
	/// Check NMI
	if( WDT_ST_WDTST == 0x01 ){
		return 1;
	} else {
		return 0;
	}
}

